# 
# copy-from-fresh-start-base.sh - try to get a fresh start base rvsn
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

command_line="$*"

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "try to copy a fresh-start base revision from an archive\\n"
                printf "usage: copy-from-fresh-start-base [options] revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --silent                      no output\\n"
                printf " --quiet                       only output errors\\n"
                printf " --default-output              default output\\n"
                printf " --report                      slightly verbose output\\n"
                printf " --verbose                     maximal output\\n"
                printf " --debug                       debugging output\\n"
                printf "\\n"
                printf "Look for a fresh-start base revision copy of REVISION in an archive.\\n"
                  printf "If one is found, copy it to the current directory and exit with status 0.\\n"
                printf "Otherwise, exit with status 1.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 


silent=1
quiet=2
default_output=3
report=4
verbose=5

verbosity=$default_output
verbose_opt=

debug_opt=

while test $# -ne 0 ; do

  case "$1" in 

    --silent)           shift
                        verbosity=$silent
                        verbose_opt=--silent
                        ;;

    --quiet)            shift
                        verbosity=$quiet
                        verbose_opt=--quiet
                        ;;

    --default-output)   shift
                        verbosity=$default_output
                        verbose_opt=--default-output
                        ;;

    --report)           shift
                        verbosity=$report
                        verbose_opt=--report
                        ;;

    --verbose)          shift
                        verbosity=$verbose
                        verbose_opt=--verbose
                        ;;

    --debug)        shift
                    arx heading "copy-from-fresh-start-base: debugging output enabled\\n"
                    set -x
                ;;

    --)                        shift
                        break
                        ;;

    -*)                        printf "copy-from-fresh-start-base: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: copy-from-fresh-start-base [options] revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

revision="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

arx valid-package-name -l -e copy-from-fresh-start-base -- "$revision"

category=`arx parse-package-name -b $revision`
branch=`arx parse-package-name $revision`
vsn=`arx parse-package-name -v $revision`
lvl=`arx parse-package-name -l $revision`


################################################################
# Greetings
# 
# This is an internal command.
# 

if test $verbosity -ge $report ; then
  ARCH__OUTLINE_DEPTH="$ARCH__OUTLINE_DEPTH*"
  arx heading "copy-from-fresh-start-base\\n"
  printf "arguments: %s\\n" "$command_line" | fold -w 60 | arx body-indent
  if test $verbosity -ge $verbose ; then
    arx heading --sub "copy-from-fresh-start-base time: %s\\n" "`date`"
    arx heading --sub "seeking revision: %s\\n" "$branch--$vsn--$lvl"
    arx heading --sub "from archive: %s\\n" "$WITHARCHIVE"
    arx heading --sub "to store in: %s\\n" "`pwd`"
  fi
fi



################################################################
# Look for Cached Copies
# 


wftp-home
wftp-cd "$category/$branch/$branch--$vsn/$lvl"


if ! wftp-get $branch--$vsn--$lvl.src.tar.gz > ,,$branch--$vsn--$lvl.src.tar.gz 2> /dev/null ; then

  rm -f ,,$branch--$vsn--$lvl.src.tar.gz

  if test $verbosity -ge $quiet ; then
    arx heading --sub "no fresh-start base revision found\\n"
    if test $verbosity -ge $verbose ; then
      arx heading --sub "copy-from-fresh-start-base finish time: %s\\n" "`date`"
    fi
  fi

  exit 1

else

  if test $verbosity -ge $report ; then
    arx heading --sub "full source revision found: %s\\n" $branch--$vsn--$lvl
  fi

  here="`pwd`"
  rm -rf ,,$branch--$vsn--$lvl
  mkdir ,,$branch--$vsn--$lvl
  cd  ,,$branch--$vsn--$lvl

  if test $verbosity -ge $verbose ; then
    $ARCH_TAR -m -zvxf ../,,$branch--$vsn--$lvl.src.tar.gz | arx body-indent --sub
  else
    $ARCH_TAR -m -zxf ../,,$branch--$vsn--$lvl.src.tar.gz
  fi

  cd $branch--$vsn--$lvl
  for f in `ls -a | grep -v -E "^\\.\\.?\$"` ; do
    mv "$f" "$here"
  done
  cd "$here"
  rm -rf ",,$branch--$vsn--$lvl"
  rm -rf ",,$branch--$vsn--$lvl.src.tar.gz"

fi

