# 
# putlast.sh - add a new sequenced directory to an archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 
errname=putlast

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "*+add a new sequenced directory to an archive from a template\\n"
                printf "usage: putlast [options] locker locker-arg source-dir dest-dir txn txn-args...\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -A --archive archive          specify the archive name\\n"
                printf " -e --errname name             program name for error messages\\n"
                printf "\\n"
                printf "Copy SOURCE-DIR to the indicated archive, creating DEST-DIR\\n"
                printf "which must not already exist.\\n"
                printf "\\n"
                printf "In addition to not already existing, DEST-DIR must be a valid\\n"
                printf "addition to its parent directory (for example, if DEST-DIR is\\n"
                printf "a new version directory, no higher numbered version may already\\n"
                printf "exist).  Whether or not DEST-DIR is valid is determined by the\\n"
                printf "helper script LOCKER.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -A|--archive)        shift
                            if test $# -eq 0 ; then
                          printf "putlast: -A and --archive require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        archive="$1"
                        shift
                        ;;

    -e|--errname)        shift
                            if test $# -eq 0 ; then
                          printf "putlast: -e and --errname require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        errname="$1"
                        shift
                        ;;

    -*)                        printf "putlast: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -lt 5 ; then
    printf "usage: putlast [options] locker locker-arg source-dir end-dir txn txn-args...\\n" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
fi

locker="$1"
shift

locker_arg="$1"
shift

source="$1"
shift

dest="$1"
shift

txn="$1"
shift

# Note that "$@" is now the arguments (if any) for the "$txn" script.



################################################################
# Sanity Check and Process Defaults
# 

if test -z "$archive" ; then
  archive=`arx my-default-archive`
fi

cd "$source"
source="`pwd`"

################################################################
# Obtain a lock in the archive
# 
# 

lockdir=`arx $locker "$locker_arg"`
wftp-home
wftp-cd $lockdir
wftp-cd +contents
there="`wftp-pwd`"

for f in `ls "$source"` ; do

  wftp-cd "$there"

  if test ! -d "$source/$f" ; then
    wftp-put "$f" < "$source/$f"

  else

    arx nested --sub arx putdir -A "$archive" "$f" "$f"
  fi
done

wftp-cd "$there"


################################################################
# Put it in place
# 

# Tell the caller (via a callback) that we are about to 
# commit.
# 
arx "$txn" --start "$@"

wftp-cd ..

wftp-rename +contents "../`basename $dest`"

# Tell the caller (via a callback) that we have finished the
# commit successfully.
# 
arx "$txn" --finish "$@"

wftp-home
wftp-rmdir $lockdir
