# 
# wd-txn.sh - project tree part of a commit or import transaction
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "*perform the project tree part of a commit or import transaction\\n"
                printf "usage: wd-txn [options] wdroot archive revision log-file\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --start                       used just prior to a commit\\n"
                printf " --finish                      used after a successful commit\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

type=neither

while test $# -ne 0 ; do

  case "$1" in 

    --start)            shift
                            type=start
                        ;;

    --finish)           shift
                        type=finish
                        ;;

    -*)                        printf "wd-txn: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 4 ; then
  printf "usage: wd-txn [options] wdroot archive revision log-file\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi


wdroot="$1"
archive="$2"
revision="$3"
logfile="$4"

################################################################
# Sanity Check and Process Defaults
# 

arx valid-archive-name -e wd-txn -- "$archive"
arx valid-package-name -e wd-txn -l -- "$revision"

if test $type = neither ; then
  printf "wd-txn: either --start or --finish must be specified\\n" 1>&2
  exit 1
fi

base=`arx parse-package-name -b $revision`
branch=`arx parse-package-name $revision`
vsn=`arx parse-package-name -v $revision`
patchlvl=`arx parse-package-name -l $revision`

################################################################
# Do it
# 

cd "$wdroot"

case $type in 

  start)        cd "$wdroot/{arch}"
                    rm -f ++mid-commit
                cp "$logfile" ++mid-commit
                exit 0
                    ;;



  finish)        cd "$wdroot/{arch}"
                  mv ++mid-commit ++commit-definite
                arx copy-to-patch-log "$logfile" $archive/$branch--$vsn $patchlvl .
                rm ++commit-definite
                exit 0
                ;;

  *)                printf "wd-txn: internal error\\n" 1>&2
                  printf "  unrecognized operator (%s)\\n" "$type" 1>&2
                printf "\\n" 1>&2
                exit 1
                ;;
                
esac
