# 
# archive-cached-revisions.sh: list revisions cached in whole-source form
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "list full source trees cached in an archive\\n"
                printf "usage: archive-cached-revisions [options] [[archive/]version]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "List the revisions cached in whole source form in VERSION.\\n"
		printf "If no version is specified, it uses the output of tree-version.\\n"
                printf "\\n"
                printf "Also see \"arx archive-cache-revision --help\"\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
cache_dir=

while test $# -ne 0 ; do

  case "$1" in 

    --)                        shift
                            break
                        ;;

    -*)                 printf "archive-cached-revisions: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: archive-cached-revisions [options] [[archive/]version]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -ne 0 ; then
  version_spec="$1"
  shift
fi

################################################################
# Sanity Check and Process Defaults
# 

if test -z "$version_spec" ; then
  version_spec="`arx tree-version`"
fi

arx valid-package-name -e archive-cached-revisions --tolerant -- "$version_spec"
archive=`arx parse-package-name --arch "$version_spec"`
version_spec=`arx parse-package-name --non-arch "$version_spec"`
category=`arx parse-package-name --basename "$version_spec"`
branch=`arx parse-package-name --package "$version_spec"`

################################################################
# Ensure that We Have an Archive Connection 
# 

if test "$WITHARCHIVE" != "$archive" ; then
  exec arx with-archive -A "$archive"  arx archive-cached-revisions "$archive/$version_spec"
fi

################################################################
# Fix This
# 

if arx valid-package-name --vsn "$version_spec" ; then
  version="$version_spec"
else
  version="`arx versions --reverse \"$archive/$version_spec\" | head -1`"
  if test -z "$version" ; then
    printf "\\n" 1>&2
    printf "archive-cached-revisions: no versions on branch.\\n" 1>&2
    printf "  archive: %s\\n" "$archive" 1>&2
    printf "  branch: %s\\n" "$version_spec" 1>&2
    printf "\\n" 1>&2
    exit 1
  fi
fi

################################################################
# Get the List
# 


for rvsn in `arx revisions "$archive/$version"` ; do

  wftp-home
  wftp-cd "$category/$branch/$version/$rvsn"
  for f in `wftp-ls` ; do
    if test "$f" = "$version--$rvsn.tar.gz" ; then
      printf "%s\\n" "$version--$rvsn"
    fi
  done

done

# tag: Tom Lord Mon Dec 10 22:09:53 2001 (archives/archive-cached-revisions.sh)
#
