# category-readme.sh: print the =README of a category
# 
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "print the =README of a category\\n"
                printf "usage: category-readme [options] [archive/]category\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Print the contents of the =README file of a particular archive\\n"
                printf "category.  If the category has no =README, nothing is printed.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                        printf "category-readme: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: category-readme [options] [[archive/]category]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -ne 0 ; then
  catspec="$1"
  shift
else
  catspec=
fi

################################################################
# Sanity Check and Process Defaults
# 

if test -z "$catspec" ; then
  catspec=`arx tree-version`
fi

arx valid-package-name -e category-readme --basename "$catspec"
archive=`arx parse-package-name --arch "$catspec"`
category=`arx parse-package-name --basename "$catspec"`

################################################################
# Establish an Archive Connection
# 

if test "$WITHARCHIVE" != "$archive" ; then
  exec arx with-archive -A "$archive" arx category-readme "$archive/$category"
fi


################################################################
# Print the List
# 

wftp-home
wftp-cd "$category"

if wftp-ls | grep -q -E "^=README$" ; then
  wftp-get =README
fi


# tag: Tom Lord Wed Jan 23 01:35:08 2002 (archives/category-readme.sh)
#
