# 
# delete-category.sh - delete a category within an archive
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
# of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "IRREVOCABLY delete category within an archive, along with all\\n"
		printf "associated branches, versions, and revisions.\\n"
                printf "usage: delete-category [options] category\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "\\n"
                printf "Delete CATEGORY as a category in the indicated archive.\\n"
                printf "\\n"
                printf "For information about how the archive to operate on is selected,\\n"
                printf "try \"arx my-default-archive --help\".\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
readme=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                        printf "delete-category: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
    printf "usage: delete-category [options] category\\n" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
fi

category="$1"

################################################################
# Sanity Check 
# 

arx valid-package-name -e delete-category -b -- "$category"
idstr="`arx my-id -e delete-category`"

archive="`arx parse-package-name --arch \"$category\"`"
category="`arx parse-package-name --basename \"$category\"`"

################################################################
# Remove the category
# 

status=0

if ! arx with-archive -A "$archive" arx arch-rmrf "$category" ; then
  printf "delete-category: unable to delete category\\n" 1>&2
  status=1
fi

exit "$status"
