# show-config.sh: show the revision frontier of a configuration
# 
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 
command_line="$*"

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "show the revision frontier of a configuration\\n"
                printf "usage: show-config [options] config-name\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -d --dir DIR                  cd to DIR first\\n"
                printf " --config-dir CFG              get config from directory CFG\\n"
                printf "\\n"
                printf "Print the revision frontier specified by the named configuration\\n"
                printf "in the CFG directory (or \"configs\" subdirectory\\n"
                printf "at the root of the project tree containing DIR).\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

dir=.
config_dir=

while test $# -ne 0 ; do

  case "$1" in 

    -d|--dir)                shift
                            if test $# -eq 0 ; then
                          printf "show-config: -d and --dir require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        dir=$1
                        shift
                        ;;

    --config-dir)       shift
                        if test $# -eq 0 ; then
                          printf "show-config: --config-dir requires an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        config_dir="$1"
                        shift
                        ;;


    --)                        shift
                            break
                        ;;

    -*)                        printf "show-config: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: show-config [options] config-name\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

name="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

cd "$dir"
dir="`pwd`"

wdroot="`arx tree-root --accurate`"
cd "$wdroot"

config_file="`arx indicated-config-file -e show-config --config-dir \"$config_dir\" --dir \"$wdroot\" --exists \"$name\"`"

################################################################
# Compute the New Configuration
# 

cd "$wdroot"


cat "$config_file" \
| arx file-syntax-filter --sh-comments --blank-lines --trailing-spaces \
| sort -k 1 \
| $ARCH_AWK -v here="$wdroot" \
       '{
          print "cd \"" here "\"" ; 
          print "printf \"%-30s\\t\" \"" $1 "\""  ;
          print "cd \"" $1 "\"" ; 
           print "x=\"`arx log-ls --full --reverse \\\"" $2 "\\\"`\"" ; 
          print "if test -z \"$x\" ; then"
          print "  printf \"show-config: no log entries for %s\\\\n\" \"" $2 "\" 1>&2"
          print "  exit 1"
          print "else"
          print "  arx log-ls --full --reverse \"" $2 "\" | head -1"
          print "fi"
        }' \
| $ARCH_SHELL -e


# tag: Tom Lord Tue Jan 29 14:02:20 2002 (configurations/show-config.sh)
#
