# 
# delete.sh - remove a file and its explicit tag
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "remove a file and its explicit inventory tag\\n"
                printf "usage: delete [options] FILE ... \\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Remove FILE (which may be a regular file, symbolic link, or directory)\\n"
                printf "and its associated explicit inventory tag.\\n"
                printf ".\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

while test $# -ne 0 ; do

  case "$1" in 

    --)                        shift
                            break
                        ;;
                        
    -*)                 printf "delete: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -lt 1 ; then
  printf "usage: delete [options] file ...\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi


################################################################
# Process Arguments
# 

here="`pwd`"
for file in "$@" ; do

  ################################################################
  # Sanity Check and Process Defaults
  # 

  cd "$here"
# We can't delete directories
  if test -d "$file" ; then
    printf "delete: can not delete directory \"%s\"\\n" "$file"
    printf "        try: rm -rf %s\\n" "$file"
  else
# We're deleting a file
    file_dir="`dirname \"$file\"`"
    file_basename="`basename \"$file\"`"
    id_file="$file_basename.id"

    cd "$file_dir"

    if test ! -e ".arch-ids/$id_file" ; then
      printf "delete: file \"%s\" not previously added\\n" "$file" 1>&2
      printf "\\n" 1>&2
      exit 1
    fi
    rm ".arch-ids/$id_file"
    cd "$here"
    rm -f "$file"
  fi

done
