# cat-library-file.sh: output a file in a revision library
# 
################################################################
# Copyright (C) 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "output a file in a revision library\\n"
                printf "usage: cat-library-file [options] file [archive/]revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --tag                         interpret FILE as an inventory tag\\n"
                printf " --this                        find the tag of FILE relative to\\n"
                printf "                                 the current directory, then find\\n"
                printf "                                 the corresponding file in the library\\n"
                printf "\\n"
                printf " -e --errname NAME             use NAME in error messages\\n"
                printf "\\n"
                printf "Print the contents of FILE in REVISION in your revision library.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

tag=
this=

errname=cat-library-file


while test $# -ne 0 ; do

  case "$1" in 

    --tag)                shift
                            tag=--tag
                        this=
                        ;;

    --this)                shift
                            tag=
                        this=--this
                        ;;

    -e|--errname)                shift
                                if test $# -eq 0 ; then
                                  printf "cat-library-file: -e and --errname require an argument\\n" 1>&2
                                  printf "try --help\\n" 1>&2
                                  exit 1
                                fi
                                errname="$1"
                                shift
                                ;;

    -*)                 printf "cat-library-file: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -lt 1 -o $# -gt 2 ; then
  printf "usage: cat-library-file [options] file [[archive/]revision]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

file="$1"
shift

if test $# -ne 0 ; then
  rvnspec="$1"
  shift
else
  rvnspec=
fi

################################################################
# Do It
# 

path="`arx library-file $this $tag \"$file\" \"$rvnspec\"`"
cat "$path"

# tag: Tom Lord Sun Jan 20 03:25:28 2002 (library/cat-library-file.sh)
#
