# library-categories.sh: list categories in the revision library
# 
################################################################
# Copyright (C) 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "list categories in the revision library\\n"
                printf "usage: library-categories [options] [archive]"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -r --reverse                  reverse the listing\\n"
                printf "\\n"
                printf "List all categories within a particular archive with records\\n"
                printf "in the revision library.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
reverse=

while test $# -ne 0 ; do

  case "$1" in 

    -r|--reverse)        shift
                            reverse=-r
                        ;;

    -*)                 printf "library-categories: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: library-categories [options] [archive]" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -gt 0 ; then
  archive="$1"
  shift
fi

################################################################
# Sanity Check and Process Defaults
# 

library="`arx my-revision-library -e library-categories`"

if test ! -z "$archive" ; then 
  arx valid-archive-name -e library-categories "$archive"
else
  archive="`arx my-default-archive`"
fi

################################################################
# Do It
# 

cd "$library"

if test ! -d "$archive" ; then
  printf "\\n" 1>&2
  printf "library-categories: archive not found in library\\n" 1>&2
  printf "  archive: %s\\n" "$archive" 1>&2
  printf "\\n" 1>&2
  exit 1
fi

cd "$archive"

for f in `ls | sort $reverse` ; do
  if arx valid-package-name --basename "$f" ; then
    printf "%s\\n" "$f"
  fi
done


# tag: Tom Lord Sun Jan 20 00:38:00 2002 (library/library-categories.sh)
#
