# library-log.sh: print a log message from the library
# 
################################################################
# Copyright (C) 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "print a log message from the library\\n"
                printf "usage: library-log [options] [archive/]revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --silent                      no output\\n"
                printf " --quiet                       only output errors\\n"
                printf " --default-output              default output\\n"
                printf " --report                      slightly verbose output\\n"
                printf " --verbose                     maximal output\\n"
                printf " --debug                       debugging output\\n"
                printf "\\n"
                printf "Print the log message for REVISION from the library.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

silent=1
quiet=2
default_output=3
report=4
verbose=5

verbosity=$default_output
verbose_opt=

debug_opt=


while test $# -ne 0 ; do

  case "$1" in 

    --silent)           shift
                        verbosity=$silent
                        verbose_opt=--silent
                        ;;

    --quiet)            shift
                        verbosity=$quiet
                        verbose_opt=--quiet
                        ;;

    --default-output)   shift
                        verbosity=$default_output
                        verbose_opt=--default-output
                        ;;

    --report)           shift
                        verbosity=$report
                        verbose_opt=--report
                        ;;

    --verbose)          shift
                        verbosity=$verbose
                        verbose_opt=--verbose
                        ;;

    --debug)        shift
                    arx heading "library-log: debugging output enabled\\n"
                    set -x
                ;;

    -*)                 printf "library-log: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: library-log [options] [archive/]revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

rvnspec="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

library="`arx my-revision-library $verbose_opt -e library-log`"

archive_revision=`arx indicated-revision -e library-log "$rvnspec"`

archive="`arx parse-package-name --arch \"$archive_revision\"`"
revision="`arx parse-package-name --non-arch \"$archive_revision\"`"
category="`arx parse-package-name --basename \"$revision\"`"
branch="`arx parse-package-name \"$revision\"`"
version="`arx parse-package-name --package-version \"$revision\"`"

################################################################
# Do It
# 

if test -d "$library/$archive/$category/$branch/$version/$revision" ; then

  cat "$library/$archive/$category/$branch/$version/$revision/,,patch-set/=log.txt"
  exit 0
    
else

  if test $verbosity -ge $quiet ; then
    printf "\\n" 1>&2
    printf "%s: revision not in library\\n" "$errname" 1>&2
    printf "  archive: %s\\n" "$archive" 1>&2
    printf "  revision: %s\\n" "$revision" 1>&2
    printf "\\n" 1>&2
  fi

  exit 1

fi  

# tag: Tom Lord Sun Jan 27 07:09:40 2002 (library/library-log.sh)
#
