# library-remove.sh: remove a revision from a revision library
# 
################################################################
# Copyright (C) 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "remove a revision from a revision library\\n"
                printf "usage: library-remove [options] [archive/]revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Remove REVISION from your revision library.\\n"
                printf "\\n"
                printf "If the revision is not present, print an error message\\n"
                printf "and exit with non-0 status.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                 printf "library-remove: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: library-remove [options] [archive/]revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

rvnspec="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

library="`arx my-revision-library -e library-remove`"

arx valid-package-name --lvl -e library-remove "$rvnspec"

path="`arx library-find -e library-remove \"$rvnspec\"`"
parent="`dirname \"$path\"`"
base="`basename \"$path\"`"

################################################################
# Do It
# 

cd "$parent"
rm -rf ,,junk
mv "$base" ,,junk
rm -rf ,,junk

# tag: Tom Lord Sun Jan 20 00:17:06 2002 (library/library-remove.sh)
#
