# library-versions.sh: list versions in the revision library
# 
################################################################
# Copyright (C) 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "list versions in the revision library\\n"
                printf "usage: library-versions [options] [[archive]/branch]"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -r --reverse                  reverse the listing\\n"
                printf "\\n"
                printf "List all versions within a particular archive/branch with\\n"
                printf "records in the revision library.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
reverse=

while test $# -ne 0 ; do

  case "$1" in 

    -r|--reverse)        shift
                            reverse=-r
                        ;;

    -*)                 printf "library-versions: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: library-versions [options] [[archive]/branch]" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -gt 0 ; then
  branchspec="$1"
  shift
fi

################################################################
# Sanity Check and Process Defaults
# 

library="`arx my-revision-library -e library-versions`"

if test ! -z "$branchspec" ; then 
  arx valid-package-name -e library-versions "$branchspec"
  archive="`arx parse-package-name --arch \"$branchspec\"`"
  category="`arx parse-package-name --basename \"$branchspec\"`"
  branch="`arx parse-package-name \"$branchspec\"`"
else
  tree_default="`arx tree-version`"
  archive="`arx parse-package-name --arch \"$tree_default\"`"
  category="`arx parse-package-name --basename \"$tree_default\"`"
  branch="`arx parse-package-name \"$tree_default\"`"
fi

################################################################
# Do It
# 

cd "$library"

if test ! -d "$archive/$category/$branch" ; then
  printf "\\n" 1>&2
  printf "library-versions: branch not found in library\\n" 1>&2
  printf "  archive: %s\\n" "$archive" 1>&2
  printf "  branch: %s\\n" "$branch" 1>&2
  printf "\\n" 1>&2
  exit 1
fi

cd "$archive/$category/$branch"

basere="([a-zA-Z]([a-zA-Z0-9]*(-[a-zA-Z0-9]+)?)*)"
vsnre="([0-9]+\\.[0-9]+)"

for f in `ls \
          | grep -E "^($basere)(--$basere)?(--$vsnre)$" \
          | sed -e "s/.*--\\([0-9].*\\)/\\1.&/" \
          | sort  -t. -k 1,1${reverse#-}n -k 2,2${reverse#-}n \
          | sed -e "s/[^.]*.[^.]*.//"` ; do

  printf "%s\\n" "$f"

done

# tag: Tom Lord Sun Jan 20 01:11:00 2002 (library/library-versions.sh)
#
