# 
# find-in-cache.sh - find a revision in the local cache
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# Minor bug fix 2003 Chris Gray
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "find a revision in the local cache\\n"
                printf "usage: find-in-cache [options] cachedir revision\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Look for a cached copy of REVISION in the project tree\\n"
                printf "which are immediate subdirectories of CACHEDIR.  If one is found,\\n"
                printf "print its location and exit with status 0.  Otherwise,\\n"
                printf "exit with status 1.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    --)                        shift
                        break
                        ;;

    -*)                        printf "find-in-cache: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 2 ; then
  printf "usage: find-in-cache [options] cachedir revision\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

cachedir="$1"
shift

revision="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

arx valid-package-name -l -e find-in-cache -- "$revision"

archive="`arx parse-package-name --arch \"$revision\"`"
category=`arx parse-package-name -b $revision`
branch=`arx parse-package-name $revision`
vsn=`arx parse-package-name -v $revision`
lvl=`arx parse-package-name -l $revision`

################################################################
# Look for Cached Copies
# 

here="`pwd`"
cd "$cachedir"
cachedir="`pwd`"

for wd in [=a-zA-Z0-9+]* ; do
  for state in locked unlocked ; do
    if test -d "$wd/{arch}/++pristine-trees/$state/$category/$branch/$branch--$vsn/$archive/$branch--$vsn--$lvl" ; then
      cd "$wd/{arch}/++pristine-trees/$state/$category/$branch/$branch--$vsn/$archive/$branch--$vsn--$lvl"
      pwd
      exit 0
    fi
  done
done

exit 1

