# 
# nested.sh: format outline-style output (nested commands)
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "format outline-style output (nested commands)\\n"
                printf "usage: nested [options] program [argument...]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " --sub                         indent for a sub-level\\n"
                printf "\\n"
                printf "Invoke PROGRAM with the heading level for formatted output\\n"
                printf "incremented by one.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

sublvl=

while test $# -ne 0 ; do

  case "$1" in 

    --sub)                shift
                            sublvl="$sublvl*"
                        ;;

    --)                        shift
                            break
                        ;;

    -*)                        printf "nested: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Set Level and Invoke Command
# 

if test -z "$ARCH__OUTLINE_DEPTH" ; then
  ARCH__OUTLINE_DEPTH="*"
fi

ARCH__OUTLINE_DEPTH="$ARCH__OUTLINE_DEPTH*$sublvl"

export ARCH__OUTLINE_DEPTH

"$@"

# tag: Tom Lord Wed Dec 12 05:51:49 2001 (output/nested.sh)
#
