# 
# copy-to-patch-log.sh - copy a log file to a patch log
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "*copy a log file to a patch log\\n"
                printf "usage: copy-to-patch-log [options] log-file [archive/]version patch-level [dir]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Record LOG-FILE as the log-entry for VERSION at PATH-LEVEL in the\\n"
                printf "project tree containing DIR (or the current directory).\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    -*)                        printf "copy-to-patch-log: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -lt 3 -o $# -gt 4 ; then
  printf "usage: copy-to-patch-log [options] log-file [archive/]version patch-level [dir]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

logfile="$1"
shift

archive_version="$1"
shift

patchlvl="$1"
shift

if test $# -ne 0 ; then
  dir="$1"
  shift
else
  dir="."
fi

here="`pwd`"

cd "$dir"
dir="`pwd`"

cd "$here"

cd "`dirname \"$logfile\"`"
logfile="`pwd`/`basename \"$logfile\"`"

################################################################
# Sanity Check and Process Defaults
# 

arx valid-package-name -e copy-to-patch-log --vsn -- "$archive_version"
arx valid-patch-level-name -e copy-to-patch-log -- "$patchlvl"

cd "$dir"
wdroot="`arx tree-root`"

archive=`arx parse-package-name --arch $archive_version`
version=`arx parse-package-name --package-version $archive_version`
category=`arx parse-package-name -b $version`
branch=`arx parse-package-name $version`

logdir="$wdroot/{arch}/$category/$branch/$version/$archive/patch-log"

################################################################
# Compute the location for the log file.
# 

mkdir -p "$logdir"
rm -f "$logdir/$patchlvl"
cp "$logfile" "$logdir/$patchlvl"

