# 
# log-for-merge.sh: generate a log entry body for a merge
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#       --version | -V
#       --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "generate a log entry bodyfor a merge\\n"
                printf "usage: log-for-merge [options] [[archive/]version]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -D --dir DIR                  use project tree containing DIR\\n"
                printf "\\n"
                printf "Generate a log entry body describing a merge into VERSION.\\n"
                printf "\\n"
                exit 0
                ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
dir=.

while test $# -ne 0 ; do

  case "$1" in 

    -D|--dir)           shift
                        if test $# -eq 0 ; then
                          printf "log-for-merge: -D and --dir require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        dir="$1"
                        shift
                        ;;

    --)                        shift
                            break
                        ;;
                        
    -*)                 printf "log-for-merge: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                  break
                        ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -gt 1 ; then
  printf "usage: log-for-merge [options] [[archive/]revision]\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

if test $# -ne 0 ; then
  version="$1"
  shift
else
  version=
fi

################################################################
# Sanity Check and Process Defaults
# 

here="`pwd`"
cd "$dir"
dir="`pwd`"
wdroot="`arx tree-root --accurate`"

cd "$wdroot"

if test -z "$version" ; then
  version=`arx tree-version`
fi

arx valid-package-name -e log-for-merge --vsn "$version"

archive="`arx parse-package-name --arch "$version"`"
version="`arx parse-package-name --non-arch "$version"`"
category="`arx parse-package-name --basename \"$version\"`"
branch="`arx parse-package-name \"$version\"`"
vsn="`arx parse-package-name --vsn \"$version\"`"

################################################################
# Print the log entry body
# 
# 

printf "Patches applied:\\n"

arx new-on-branch --reverse "$archive/$version" \
| xargs need-args 'arx log-ls --full --summary' \
| $ARCH_AWK 'match($0, "^[^ \t]") { printf("\n  * %s\n", $0); }
       match($0, "^[ \t]")  { printf(" %s\n", $0); }'

printf "\\n"


# tag: Tom Lord Wed Jan  9 01:53:56 2002 (patch-logs/log-for-merge.sh)
#
