# remove-log.sh: remove a version patch log from a project tree
# 
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "remove a version patch log from a project tree\\n"
                printf "usage: remove-log [options] [archive/]version\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf " -d --dir DIR                  cd to DIR first\\n"
                printf "\\n"
                printf "Remove the patch log for VERSION from the project tree containing DIR\\n"
                printf "(or the current directory).\\n"
                printf "\\n"
                printf "Use this command with caution -- it erases revision history from\\n"
                printf "the project tree!\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=
dir=.

while test $# -ne 0 ; do

  case "$1" in 

    -d|--dir)                shift
                        if test $# -eq 0 ; then
                          printf "remove-log: -d and --dir require an argument\\n" 1>&2
                          printf "try --help\\n" 1>&2
                          exit 1
                        fi
                        dir="$1"
                        shift
                        ;;

    -*)                        printf "remove-log: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 1 ; then
  printf "usage: remove-log [options] [archive/]version\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

arch_version="$1"

################################################################
# Sanity Check
# 

cd "$dir"
dir="`pwd`"

arx valid-package-name -e "remove-log" --vsn -- "$arch_version"

archive=`arx parse-package-name --arch "$arch_version"`
version=`arx parse-package-name --package-version "$arch_version"`
category=`arx parse-package-name -b $version`
branch=`arx parse-package-name $version`

cd "$dir"
wdroot="`arx tree-root --accurate`"

arch_logdir="$wdroot/{arch}/$category/$branch/$version/$archive"

if test ! -e "$arch_logdir" ; then
  printf "remove-log: patch log not found\\n" 1>&2
  printf "  source tree: %s\\n" "$wdroot" 1>&2
  printf "  version: %s/%s\\n" $archive $version 1>&2
  printf "\\n" 1>&2
  printf "try arx logs --help\\n" 1>&2
  printf "\\n" 1>&2
  exit 1
fi


################################################################
# Do It
# 

rm -rf "$arch_logdir"

# tag: Tom Lord Thu Feb 14 16:39:21 2002 (patch-logs/remove-log.sh)
#
