# 
# patch-add-log.sh: add a new log file to a patch set
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
# of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 

comand_line="$*"

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "add a new log file to a patch set\\n"
                printf "usage: patch-add-log [options] [--] patch-set-dir archive/revision log-file\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Modify the patch set in PATCH-SET-DIR so that it includes the\\n"
                printf "addition of LOG-FILE as a new file as a patch-log entry for\\n"
                printf "ARCHIVE/REVISION\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

archive=

while test $# -ne 0 ; do

  case "$1" in 

    --)                        shift
                            break
                        ;;
                        
    -*)                        printf "patch-add-log: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;

  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 3 ; then
  printf "usage: patch-add-log [options] [--] patch-set-dir archive/revision log-file\\n" 1>&2
  printf "try --help\\n" 1>&2
  exit 1
fi

delta="$1"
shift

archive_revision="$1"
shift

logfile="$1"
shift

################################################################
# Sanity Check and Process Defaults
# 

here="`pwd`"

cd "$delta"
delta="`pwd`"

cd "$here"
cd "`dirname \"$logfile\"`"
logfile="`pwd`/`basename \"$logfile\"`"

arx valid-package-name -e patch-add-log --patch-level "$archive_revision"

archive=`arx parse-package-name --arch "$archive_revision"`
revision=`arx parse-package-name --non-arch "$archive_revision"`
category=`arx parse-package-name --basename "$revision"`
branch=`arx parse-package-name --package "$revision"`
version=`arx parse-package-name --package-version "$revision"`
lvl=`arx parse-package-name --lvl "$revision"`



################################################################
# Do It
# 

cd "$delta"

new_file="./{arch}/$category/$branch/$version/$archive/patch-log/$lvl"
new_file_tag="A_$new_file"

if grep -s -F -e "$new_file	$new_file_tag" mod-files-index ; then
  printf "patch-add-log: patch already has entry for that log file\\n" 1>&2
  printf "\\n" 1>&2
  exit 1
fi

if grep -s -F -e "$new_file	$new_file_tag" orig-files-index ; then
  printf "patch-add-log: patch already removes that log file\\n" 1>&2
  printf "\\n" 1>&2
  exit 1
fi

mv mod-files-index ,,tmp
printf "%s %s\\n" "$new_file" "$new_file_tag" > ,,tmp2
sort -m -k 2 ,,tmp ,,tmp2 > mod-files-index
rm ,,tmp ,,tmp2

# Because of the reliable tagging for {arch} directories,
# and the automatic creation of dirs needed for new files,
# there is no need to add directories containing this patch
# log entry.
# 

mkdir -p "new-files-archive/`dirname \"$new_file\"`"
cp -p "$logfile" "new-files-archive/$new_file"


# tag: Tom Lord Thu Dec 13 02:30:24 2001 (patch-sets/patch-add-log.sh)
#
