# 
# with-archive-settings.sh: report with-archive env. settings
################################################################
# Copyright (C) 2001, 2002 Tom Lord
# Copyright (C) 2002, 2003 Walter Landry and the Regents of the
#                                  University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA
# 

set -e 
errname=with-archive-settings

################################################################
# special options
# 
# Some options are special:
# 
#        --version | -V
#        --help | -h
# 
if test $# -ne 0 ; then

  for opt in "$@" ; do
    case $opt in

      --version|-V) exec arx --version
                    ;;


      --help|-h)
                printf "report with-archive environment settings\\n"
                printf "usage: with-archive-settings [options]\\n"
                printf "\\n"
                printf " -V --version                  print version info\\n"
                printf " -h --help                     display help\\n"
                printf "\\n"
                printf "Return a shell script that restores the environment variables\\n"
                   printf "used by \"arx with-archive\" to their current values.\\n"
                printf "\\n"
                exit 0
                      ;;

      *)
                ;;
    esac
  done
fi

################################################################
# Ordinary Options
# 
# 

while test $# -ne 0 ; do

  case "$1" in 

    -*)                        printf "with-archive-settings: unrecognized option (%s)\\n" "$1" 1>&2
                        printf "try --help\\n" 1>&2
                        exit 1
                        ;;

    *)                        break
                            ;;
  esac

done



################################################################
# Ordinary Arguments
# 

if test $# -ne 0 ; then
    printf "usage: with-archive-settings [options]\\n" 1>&2
    printf "try --help\\n" 1>&2
    exit 1
fi

################################################################
# The Answer
#

printf "WITHARCHIVE='%s' ; \\\\\\n" "$WITHARCHIVE" 
printf "WITHARCHIVELOC='%s' ; \\\\\\n" "$WITHARCHIVELOC" 

printf "WFTP_MY_ADDR='%s' ; \\\\\\n" "$WFTP_MY_ADDR" 
printf "WFTP_SITE='%s' ; \\\\\\n" "$WFTP_SITE" 
printf "WFTP_SECRET='%s' ; \\\\\\n" "$WFTP_SECRET" 
printf "WFTP_SITE_ADDR='%s' ; \\\\\\n" "$WFTP_SITE_ADDR" 
printf "WFTP='%s'\\n" "$WFTP" 

# tag: Tom Lord Sat Jan  5 12:21:06 2002 (remote/with-archive-settings.sh)
#
