/* Print registered archives and their locations

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */


#include <list>
#include <string>
#include <iostream>
#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "get_option_from_file.hpp"
#include "command_initializer.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

int archives(list<std::string> &argument_list, const command &cmd);

static command_initializer archives_init(command("archives",
"Print registered archives and their locations",
"usage: archives [options]",
"-n --names               print archive names only\n\
-l --locations            print archive locations only\n\
\n\
Print a list of registered archives and their locations.\n\
The options -n (--names) and -l (--locations) cancel each other.",
archives,"User",true));

int archives(list<string> &argument_list, const command &cmd)
{
  bool print_names(true), print_locations(true);
  Command_Info info(cmd);

  bool done=false;
  while(!argument_list.empty() && !done)
    {
      if(!parse_common_options(argument_list,info))
        {
          list<string>::iterator arg=argument_list.begin();
          if(*arg=="-n" || *arg=="--names")
            {
              print_locations=false;
              print_names=true;
              argument_list.pop_front();
            }
          else if(*arg=="-l" || *arg=="--locations")
            {
              print_locations=true;
              print_names=false;
              argument_list.pop_front();
            }
          else
            {
              parse_unknown_options(argument_list,info);
              done=true;
            }
        }
    }
  check_extra_args(argument_list,info);

  path home(getenv("HOME"));
  for(fs::directory_iterator i(home / ".arch-params" / "=locations");
      i!=fs::directory_iterator(); ++i)
    {
      string location;
      if(print_locations)
        {
          location=get_option_from_file(*i,info);
        }

      if(print_names && print_locations)
        {
          cout << i->leaf()
               << "\n\t" << location << "\n";
        }
      else if(print_names)
        {
          cout << i->leaf() << "\n";
        }
      else
        {
          cout << location << "\n";
        }
    }
  return 0;
}
