/* Delete a file or empty directory and its explicit tag.  It should
   have the same semantics and most of the same options as rm(1).

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "command_initializer.hpp"
#include "get_config_option.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

int delete_path(list<string> &argument_list, const command &cmd);

static command_initializer move_init(command("delete",
"Delete a file or empty directory and its explicit tag.",
"usage: delete [options] source...",
"Delete a file or empty directory and its explicit tag.",
delete_path,"Inventory",true));

int delete_path(list<string> &argument_list, const command &cmd)
{
  Command_Info info(cmd);

  while(parse_common_options(argument_list,info))
    {}
  parse_unknown_options(argument_list,info);

  if(argument_list.empty())
    {
      throw arx_error("Need at least one file name",info);
    }

  for(list<string>::iterator file=argument_list.begin();
      file!=argument_list.end(); ++file)
    {
      const path filename(*file);
      /* Id file location and name is different for files and
         directories. */
      if(is_directory(filename))
        {
          id_directory=filename / ".arch-ids";
          id_file_path=id_directory / "=id";
        }
      else
        {
          id_directory=filename.branch_path() / ".arch-ids";
          id_file_path=id_directory / (filename.leaf() + ".id");
        }

      if(!exists(id_directory) || !exists(id_file_path))
        {
        }
        create_directory(id_directory);
      if(exists(id_file_path) && info.verbosity>=default_output)
        cerr << *file << " already added\n";
      else
        {
          fs::ofstream id_file(id_file_path);
          id_file << get_config_option("=id",info) << " "
                  << to_iso_extended_string(ptime
                                            (second_clock::universal_time()))
                  << "." << count << endl;
        }
    }
  return 0;
}
