/* Move added files to a temp directory where they will later be moved
   to their final destination.

  Copyright (C) 2003 Walter Landry
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */

#include <string>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/convenience.hpp"
#include <list>
#include <utility>
#include "Moved_Path.hpp"
#include <sstream>
#include "move_original_away.hpp"
#include "recursively_delete_paths.hpp"
#include "check_symlink_hierarchy.hpp"
#include "Command_Info.hpp"
#include <iostream>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void add_files_and_directories(list<Moved_Path> &new_paths,
                               const path &patch, const path &source,
                               const path &temp_path,
                               list<Moved_Path> &moved,
                               const Command_Info &info)
{
  /* Sort so that the topmost directories are first. */

  new_paths.sort(Moved_Path_destination_cmp);
  
  /* Then flatten the directory hierarchy, starting with the
     bottom-most. */

  int adds(0);
  for(list<Moved_Path>::reverse_iterator i=new_paths.rbegin();
      i!=new_paths.rend(); ++i)
    {
      stringstream added;
      added << ",,added-" << adds;
      i->initial=added.str();

      /* If it is a directory, delete all of the contents.  The
         contents should only be directories, if anything. */

      const path location(patch/"new-files-archive"/i->destination);

      /* Make sure we aren't moving things from symlinks. */
      check_symlink_hierarchy(patch,location);

      if(info.debug)
        cout << "Deleting subdirectories: "
             << location.native_file_string() << endl;

      if(!is_link(location) && is_directory(location))
        {
          for(fs::directory_iterator j(location); j!=fs::directory_iterator();
              ++j)
            {
              recursively_delete_paths(*j);
            }
        }


      if(info.debug)
        cout << "Renaming: " << location.native_file_string()
             << "\t" << (temp_path/i->initial).native_file_string() << endl;


      fs::rename(location,temp_path/i->initial);
      i->destination=source/i->destination;
      ++adds;
    }

  /* Finally, splice the moved list into the total list of moved
     files. */
  moved.splice(moved.end(),new_paths);
}
