/* Move all of the deletes and renames to their final resting place.

  Copyright (C) 2003 Walter Landry
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/convenience.hpp"
#include "Moved_Path.hpp"
#include <list>
#include "move_original_away.hpp"
#include "check_symlink_hierarchy.hpp"
#include "Command_Info.hpp"
#include <iostream>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void move_to_destination(list<Moved_Path> &moved, const path &deleted_path,
                         const path &source,
                         list<pair<string,string> > &move_conflicts,
                         const Command_Info &info)
{
  /* Sort the moved list so that topmost destinations come first. */

  moved.sort(Moved_Path_destination_cmp);

  /* Now move everything (adds, renames and deletes). */

  for(list<Moved_Path>::iterator i=moved.begin(); i!=moved.end(); ++i)
    {
      /* Make sure we aren't moving things from symlinks. */
      check_symlink_hierarchy(source,i->destination);

      if(info.debug)
        cout << "Creating directories: "
             << (i->destination.branch_path()).native_file_string() << endl;

      fs::create_directories(i->destination.branch_path());
      if(exists(i->destination))
        {
          move_original_away(i->destination.string(),move_conflicts);
        }

      if(info.debug)
        cout << "Renaming: " << (deleted_path/i->initial).native_file_string()
             << "\t" << i->destination.native_file_string() << endl;

      fs::rename(deleted_path/i->initial,i->destination);
    }
}
