/* Read and set the permissions of directories in the patch, creating
   them if necessary.  This is kind of bogus.  The directories should
   already exist.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <bitset>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/convenience.hpp"
#include "set_permissions.hpp"
#include "Command_Info.hpp"
#include "arx_error.hpp"
#include "check_symlink_hierarchy.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void read_and_set_directory_permissions(const path &permissions_path,
                                        const path &patches,
                                        const Command_Info &info)
{
  if(exists(permissions_path))
    {
      if(is_link(permissions_path))
        {
          throw arx_error("Bad Patch.  Permissions file is a symlink, not a regular file\n\t"
                          + permissions_path.native_file_string(),info);
        }
      fs::ifstream permissions_file(permissions_path);
      
      unsigned long permission;
      string dummy, dir_path;
      
      /* We have to read permissions in octal mode. */
      permissions_file >> oct;
      
      while(permissions_file >> dummy >> permission >> dir_path)
        {
          if(dummy!="--permissions")
            throw arx_error("Bad Patch: Bad format in file\n\t"
                            + permissions_path.string(),info);
          
          /* Strip the leading "./" from the paths.  It causes
             problems with boost. */
          if(dir_path.size()>=2 && dir_path.substr(0,2)=="./")
            {
              dir_path=dir_path.substr(2);
            }
          
          check_symlink_hierarchy(patches,patches/dir_path);
          
          if(!fs::exists(patches/dir_path))
            create_directories(patches/dir_path);
          
          set_permissions(patches/dir_path,bitset<9>(permission));
        }
    }
}
