/* Read a list of files and inventory tags from a file.

  Copyright (C) 2003 Walter Landry
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include <list>
#include "arx_error.hpp"
#include "Command_Info.hpp"
#include "url_decode.hpp"
#include "check_if_local_path.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

inline bool second_element_cmp(const pair<string,string> &s1,
                               const pair<string,string> &s2)
{
  return s1.second < s2.second;
}

void read_and_sort_index(const path &file_path,
                         list<pair<string,string> > &file_list,
                         const Command_Info &info)
{
  if(exists(file_path))
    {
      if(is_link(file_path))
        {
          throw arx_error("Bad patch.  Index file is a symlink, not a regular file.\n\t"
                          + file_path.native_file_string(),info);
        }
      fs::ifstream infile(file_path);
      string file_name, encoded_file_name, inventory_tag;
      while(infile >> encoded_file_name >> inventory_tag)
        {
          file_name=url_decode(encoded_file_name,info);
          check_if_local_path(file_name,info);

          /* Strip the leading "./" from the paths.  It causes
             problems with boost. */
          if(file_name.size()>=2 && file_name.substr(0,2)=="./")
            {
              file_name=file_name.substr(2);
            }
            
          file_list.push_back(make_pair(file_name,inventory_tag));
        }
      if(!infile.eof())
        {
          throw arx_error("Error when reading an index file\n\t"
                          + file_path.native_file_string(),info);
        }
    }

  file_list.sort(second_element_cmp);
}
