/* A generic mechanism to get or set configuration variables (my-id,
   my-editor, etc.)

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <iostream>
#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "get_config_option.hpp"
#include "set_config_option.hpp"
#include "command_initializer.hpp"
#include "arx_error.hpp"

using namespace std;

int generic_config(list<string> &argument_list, const command &cmd);

// static command_initializer my_hook_dir_init(command("my-hook-dir",
// "print or set your default hook directory",
// "usage: my-hook-dir [options] [dir]",
// "-d --delete                   unspecify your library location\n\
// \n\
// With no argument, and without -d, print the path to your default hook directory\n\
// \n\
// With an argument, record DIR as the path to your default hook\n\
// directory\n\
// \n\
// With the option -d (--delete) and no argument, ensure that\n\
// you do not have a default notify directory path set in ~/.arch-params.",
// generic_config,"User",true));

static command_initializer my_browser_init(command("my-browser",
"print or change your default ArX browser",
"usage: my-browser [options] [browser-string]",
"-d --delete                   unspecify your default browser\n\
\n\
With no argument, and without -d, print your default ArX browser.\n\
\n\
With an argument, record BROWSER-STRING your default ArX browser.\n\
\n\
With the option -d (--delete) and no argument, ensure that\n\
you do not have a default browser in ~/.arch-params.",
generic_config,"User",true));

static command_initializer my_editor_init(command("my-editor",
"print or change your default ArX editor",
"usage: my-editor [options] [editor-string]",
"-d --delete                   unspecify your default editor\n\
\n\
With no argument, and without -d, print your default ArX editor.\n\
\n\
With an argument, record EDITOR-STRING your default ArX editor.\n\
\n\
With the option -d (--delete) and no argument, ensure that\n\
you do not have a default editor in ~/.arch-params.",
generic_config,"User",true));

static command_initializer my_guidiff_init(command("my-guidiff",
"print or change your default ArX guidiff",
"usage: my-guidiff [options] [guidiff-string]",
"-d --delete                   unspecify your default guidiff\n\
\n\
With no argument, and without -d, print your default ArX guidiff.\n\
\n\
With an argument, record GUIDIFF-STRING your default ArX guidiff.\n\
\n\
With the option -d (--delete) and no argument, ensure that\n\
you do not have a default guidiff in ~/.arch-params.",
generic_config,"User",true));

static command_initializer my_default_archive_init(command("my-default-archive",
"print or change your default ArX archive",
"usage: my-default-archive [options] [default-archive-string]",
"-d --delete                   unspecify your default archive\n\
\n\
With no argument, and without -d, print your default ArX archive.\n\
\n\
With an argument, record DEFAULT-ARCHIVE-STRING your default ArX archive.\n\
\n\
With the option -d (--delete) and no argument, ensure that\n\
you do not have a default archive in ~/.arch-params.",
generic_config,"User",true));

int generic_config(list<string> &argument_list, const command &cmd)
{
  bool delete_option(false), set_option(false);
  Command_Info info(cmd);

  bool done=false;
  while(!argument_list.empty() && !done)
    {
      if(!parse_common_options(argument_list,info))
        {
          list<string>::iterator arg=argument_list.begin();
          if(*arg=="-d" || *arg=="--delete")
            {
              delete_option=true;
              argument_list.pop_front();
            }
          else
            {
              parse_unknown_options(argument_list,info);
              done=true;
            }
        }
    }
  string new_option;
  if(!delete_option && !argument_list.empty())
    {
      new_option=*(argument_list.begin());
      set_option=true;
      argument_list.pop_front();
    }
  check_extra_args(argument_list,info);
  
  /* Get the filename by removing the 'my-' prefix to the name */
  string filename("=" + cmd.name.substr(3));

  if(set_option || delete_option)
    {
      set_config_option(filename,new_option,info);
    }
  else
    {
      string temp(get_config_option(filename,info));
      if(temp.empty())
        {
          throw arx_error("no default set",info);
        }
      else if(info.verbosity>=default_output)
        cout << temp << endl;
    }
  return 0;
}
