/* Returns the strong, weak, or naming convention tag for a directory.

   Copyright (C) 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "Inventory_Flags.hpp"
#include "Inventory_Method.hpp"
#include "inventory_types.hpp"
#include "Command_Info.hpp"
#include "names_tag.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

string get_implicit_directory_tag(const path &dir_path,
                                  const Inventory_Flags &flags,
                                  const Command_Info &info)
{
  /* First, check for strong tags */
  if(exists(dir_path / ".arch-ids/=all"))
    {
      return "a_" + get_option_from_file((dir_path / ".arch-ids/=all"),
                                         info) + "./.";
    }
  /* Next, check for weak tags */
  else if(exists(dir_path / ".arch-ids/=default"))
    {
      return "w_" + get_option_from_file((dir_path / ".arch-ids/=default"),
                                         info) + "./.";
    }
  /* Finally, just use the name */
  else
    {
      string prefix("?");;
      if(flags.inv_method==Inventory_Method::implicit_inventory)
        prefix+="_";
      return prefix + names_tag(dir_path,info);
    }
}
