/* Checks whether a particular directory is categorized as control.
   If so, and we are inventorying control directories, then recurse
   through it.

   Copyright (C) 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "boost/filesystem/operations.hpp"
#include "boost/regex.hpp"
#include "Inventory_Flags.hpp"
#include "Inventory_Method.hpp"
#include "file_attributes.hpp"
#include "inventory_types.hpp"
#include "inventory_directory.hpp"
#include "inventory_directory_as.hpp"
#include "Inventory.hpp"

#include "names_tag.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

bool inventory_control_directory(const path &file_path,
                                 Inventory &result,
                                 const Inventory_Flags &flags,
                                 const Command_Info &info)
{
  if(regex_match(file_path.leaf(),flags.regexes.control))
    {
      if(flags.control)
        {
          /* {arch} directories are always names tagged with
             the default naming conventions. */
          if(file_path.leaf()=="{arch}")
            {
              string prefix;
              /* Unfortunately, the prefix for {arch}
                 directories depends on whether you are using
                 names_inventory or something else. Names uses
                 "?, and implicit and explicit use "A_". */
              if(flags.inv_method==Inventory_Method::names_inventory)
                {
                  prefix="?";
                }
              else
                {
                  prefix="A_";
                }
              
              if(flags.directories)
                result[control][arx_dir]
                  .push_back(file_attributes
                             (file_path,prefix + names_tag(file_path,info)));
              Inventory_Flags new_flags(flags);
              new_flags.inv_method=Inventory_Method::names_inventory;
              new_flags.source=true;
              /* We create a new set of results, and then
                 splice the source results to the grand list
                 of control results.  We have to replace the
                 tags before we splice.  All of the other
                 results get spliced directly. */
              Inventory control_result;

              inventory_directory(file_path,control_result,new_flags,info);

              for(int j=0;j<2;++j)
                {
                  /* Need to fix for non-names inventories. */
                  if(flags.inv_method
                     !=Inventory_Method::names_inventory)
                    {
                      for(Inventory_iterator
                            i=control_result[source][j].begin();
                          i!=control_result[source][j].end(); ++i)
                        {
                          i->inventory_tag="A_"
                            + i->inventory_tag.substr(1);
                        }
                    }

                  /* Splice it in */
                  result[control][j].
                    splice(result[control][j].begin(),
                           control_result[source][j]);
                }
              
              for(int j=0; j<num_inventory_types; ++j)
                for(int k=0; k<2; ++k)
                  {
                    result[j][k].splice(result[j][k].begin(),
                                        control_result[j][k]);
                  }
            }
          else
            /* .arch-ids are always control. */
            {
              string prefix;
              /* Unfortunately, the prefix for .arch-ids
                 directories depends on whether you are using
                 names_inventory or something else. Names uses
                 "?, and implicit and explicit use "D_". */
              if(flags.inv_method==Inventory_Method::names_inventory)
                {
                  prefix="?";
                  inventory_directory_as(file_path,result,control,flags,info,true);
                }
              else
                {
                  prefix="D_";
                  inventory_directory_as(file_path,result,control,flags,info);
                }

              if(flags.directories)
                result[control][arx_dir]
                  .push_back(file_attributes
                             (file_path,prefix + names_tag(file_path,info)));
            }
        }
      return true;
    }
  return false;
}
