/* Inventories a directory, but puts everything into the a particular
   category (control, precious, junk, etc.).  Useful for inventorying
   a directory that has already been determined to be control,
   precious, junk, etc.

   Copyright (C) 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "inventory_types.hpp"
#include "Inventory_Flags.hpp"
#include "file_attributes.hpp"
#include "Command_Info.hpp"
#include "get_option_from_file.hpp"
#include "names_tag.hpp"
#include "Inventory.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void inventory_directory_as
(const path &directory,
 Inventory &result,
 const inventory_types &type,
 const Inventory_Flags &flags,
 const Command_Info &info,
 const bool &control_uses_names=false)
{
  fs::directory_iterator end;

  for(fs::directory_iterator i(directory); i!=end; ++i)
    {
      /* If it is a directory, we have to recurse through it.
         Symbolic links are always considered files, even if they
         point to directories. */
      
      if(is_directory(*i) && !is_link(*i))
        {
          if(flags.directories)
            result[type][arx_dir].push_back(*i);
          inventory_directory_as(*i,result,type,flags,info);
        }
      else if(flags.files)
        {
          if(type!=control)
            {
              result[type][arx_file].push_back(*i);
            }
          else
            /* Control files have tags, while the other non-source
               categories don't. */
            {
              /* This is so broken.  The type of tag for .arch-ids
                 files shouldn't depend on the naming convention. */
              if(!control_uses_names)
                {
                  result[control][arx_file].
                    push_back(file_attributes
                              (*i,"E_" + get_option_from_file(*i,info)));
                }
              else
                {
                  result[control][arx_file].
                    push_back(file_attributes
                              (*i,"?" + names_tag(*i,info)));
                }
            }
        }
    }
}
