/* Compare the directories that are in both the original and modified
   trees, looking only at the permissions bits and renames.  Write out
   the appropriate files in the patch-directory if they are different.

  Copyright (C) 2001, 2002 Tom Lord
  Copyright (C) 2002, 2003 Walter Landry and the Regents
                           of the University of California
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "file_attributes.hpp"
#include "arx_error.hpp"
#include "inventory_types.hpp"
#include <list>
#include <utility>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void compare_directories(list<pair<file_attributes,file_attributes> >
                         in_both[num_inventory_types][2],
                         list<file_attributes> changed_orig[2],
                         list<file_attributes> changed_mod[2],
                         const path &destination)
{
  for(int l=0;l<num_inventory_types;++l)
    for(list<pair<file_attributes,file_attributes> >::iterator
          i=in_both[l][arx_dir].begin(); i!=in_both[l][arx_dir].end(); ++i)
      {
        file_attributes &orig(i->first), &mod(i->second);

        if(orig.file_path.string()!=mod.file_path.string())
          {
            /* Check for renames */
            changed_orig[arx_dir].push_back(orig);
            changed_mod[arx_dir].push_back(mod);            
          }
        
        if(orig.permissions!=mod.permissions)
          {
            fs::ofstream orig_file(destination/mod.file_path/"=dir-meta-orig");
            orig_file << "--permissions "
                      << oct << orig.permissions.to_ulong() << endl;
            fs::ofstream mod_file(destination/mod.file_path/"=dir-meta-mod");
            mod_file << "--permissions "
                     << oct << mod.permissions.to_ulong() << endl;

            changed_orig[arx_dir].push_back(orig);
            changed_mod[arx_dir].push_back(mod);            
          }
      }
}
