/* Create a patch between two source trees.  This just parses the
   arguments and passes it on to make_patch.

  Copyright (C) 2001, 2002 Tom Lord
  Copyright (C) 2002, 2003 Walter Landry and the Regents
                           of the University of California
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */


#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "command_initializer.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"
#include <list>
#include "Inventory_Flags.hpp"
#include "make_patch.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

int mkpatch(list<string> &argument_list, const command &cmd);

static command_initializer mkpatch_init(command("mkpatch",
"Create a patch between two source trees",
"usage: mkpatch [options] original modified destination",
"Create a patch tree between SOURCE and MODIFIED in DESTINATION\n\
DESTINATION must not already exist.\n\
\n\
See also \"dopatch --help\"",
mkpatch,"Patch Set",true));

int mkpatch(list<string> &argument_list, const command &cmd)
{
  Command_Info info(cmd);
  Inventory_Flags flags;


  while(!argument_list.empty())
    if(!parse_common_options(argument_list,info))
      {
        parse_unknown_options(argument_list,info);
        break;
      }

  path original, modified, destination;
  if(argument_list.size()!=3)
    {
      string arg_list;
      for(list<string>::iterator i=argument_list.begin();
          i!=argument_list.end(); ++i)
        {
          arg_list+="\n\t" + *i;
        }
      throw arx_error("Wrong number of arguments to mkpatch.  Arguments are"
                      + arg_list, info);
    }
  else
    {
      original=path(*(argument_list.begin()));
      argument_list.pop_front();
      modified=path(*(argument_list.begin()));
      argument_list.pop_front();
      destination=path(*(argument_list.begin()));
      argument_list.pop_front();
    }
  make_patch(original,modified,destination,info);
  return 0;
}
