/* Save the permissions for a set of directories.

  Copyright (C) 2001, 2002 Tom Lord
  Copyright (C) 2002, 2003 Walter Landry and the Regents
                           of the University of California
  
  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 dated June, 1991.

  This program is distributed in the hope that it will be useful, but
  WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
  USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "file_attributes.hpp"
#include "arx_error.hpp"
#include "Command_Info.hpp"
#include "Inventory.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void save_directory_permissions(Inventory &inv,
                                list<file_attributes> &changed_list,
                                const path &prefix,
                                const path &destination)
{
  list<file_attributes> sorted_list;
  for(int l=0;l<num_inventory_types;++l)
    {
      sorted_list.splice(sorted_list.begin(),inv[l][arx_dir]);
    }
  if(!sorted_list.empty())
    {
      sorted_list.sort();
      fs::ofstream destination_file(destination);
      destination_file << oct;
      for(Inventory_iterator i=sorted_list.begin();
          i!=sorted_list.end(); ++i)
        {
          destination_file << "--permissions " << i->permissions.to_ulong()
                           << "\t" << i->file_path.native_file_string()
                           << "\n";
        }
      changed_list.splice(changed_list.begin(),sorted_list);
    }
}

