/* Record the location of an archive.

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "command_initializer.hpp"
#include "create_archive_registration.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/exception.hpp"
#include "arx_error.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

int register_archive(list<string> &argument_list, const command &cmd);

static command_initializer register_archive_init(command("register-archive",
"Record the location of an archive",
"usage: register-archive [options] archive location",
"-d --delete                   remove a registered archive\n\
\n\
Record the location of an archive.  You must register the location\n\
of an archive before you can access it.\n\
\n\
With the option -d (--delete), remove the registration of a previously\n\
registered archive.",
register_archive,"User",true));

int register_archive(list<string> &argument_list, const command &cmd)
{
  bool delete_option(false);
  Command_Info info(cmd);

  bool done=false;
  while(!argument_list.empty() && !done)
    {
      if(!parse_common_options(argument_list,info))
        {
          list<string>::iterator arg=argument_list.begin();
          if(*arg=="-d" || *arg=="--delete")
            {
              delete_option=true;
              argument_list.pop_front();
            }
          else
            {
              parse_unknown_options(argument_list,info);
              done=true;
            }
        }
    }
  if(argument_list.size()<1)
    {
      throw arx_error ("Not enough arguments",info);
    }
  string archive(*(argument_list.begin())), location;
  argument_list.pop_front();
  if(!delete_option)
    {
      if(argument_list.empty())
        {
          throw arx_error ("Not enough arguments",info);
        }
      else
        {
          location=*(argument_list.begin());
          argument_list.pop_front();
        }
    }      
  check_extra_args(argument_list,info);
  
  /* Delete the registration */
  if(delete_option)
    {
      path home(getenv("HOME"));
      path config_path(home / ".arch-params/=locations" / archive);
      
      if(!exists(config_path))
        {
          throw arx_error("Archive is not registered: " + archive,info);
        }
      else
        {
          try
            {
              remove(config_path);
            }
          catch(fs::filesystem_error &fs_error)
            {
              throw arx_error("Could not delete archive registration: "
                              + archive, info);
            }
        }
    }
  /* Or create a new one */
  else
    {
      create_archive_registration(archive,location,info);
    }
  
  return 0;
}
