/* Print or set the inventory tagging method for a project tree.

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */


#include "boost/filesystem/operations.hpp"
#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "command_initializer.hpp"
#include "Inventory_Method.hpp"
#include <iostream>
#include <string>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

int tagging_method(list<string> &argument_list, const command &cmd);

static command_initializer tagging_method_init(command("tagging-method",
"print or set a project tree tagging method",
"usage: tagging-method [options] [method]",
"Change the method by which source files are identified.\n\
It must be one of:\n\
\n\
\tnames     use naming conventions only\n\
\timplicit  use naming conventions but permit inventory tags\n\
\t          (internal or externl)\n\
\texplicit  require explicit external tags",
tagging_method,"Inventory",true));

int tagging_method(list<string> &argument_list, const command &cmd)
{
  bool set_option(false);
  Command_Info info(cmd);

  bool done=false;
  while(!argument_list.empty() && !done)
    {
      if(!parse_common_options(argument_list,info))
        {
          parse_unknown_options(argument_list,info);
          done=true;
        }
    }
  string new_option;

  if(!argument_list.empty())
    {
      new_option=*(argument_list.begin());
      set_option=true;
      argument_list.pop_front();
    }
  check_extra_args(argument_list,info);
  
  if(set_option)
    {
      Inventory_Method::inventory_method method;

      if(new_option=="names")
        method=Inventory_Method::names_inventory;
      else if(new_option=="explicit")
        method=Inventory_Method::explicit_inventory;
      else if(new_option=="implicit")
        method=Inventory_Method::implicit_inventory;
      Inventory_Method::set(method,fs::current_path(),info);
    }
  else
    {
      switch(Inventory_Method::get(fs::current_path(),info))
        {
        case Inventory_Method::names_inventory:
          cout << "names" << endl;
          break;
        case Inventory_Method::explicit_inventory:
          cout << "explicit" << endl;
          break;
        case Inventory_Method::implicit_inventory:
          cout << "implicit" << endl;
          break;
        default:
          throw arx_error("Internal Error:  Unrecognized inventory type ",
                          info);
        }
    }
  return 0;
}

