/* Returns the location of an archive

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "arx_error.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

string archive_location(const string &archive, const Command_Info &info)
{
  path home(getenv("HOME"));
  path config_path(home / ".arch-params/=locations" / archive);

  string location;
  if(!exists(config_path))
    {
      throw arx_error("Archive is not registered: " + archive, info);
    }
  else
    {
      fs::ifstream config_file(config_path);
      if(!getline(config_file,location))
        {
          throw arx_error("Could not open location file: "
                          + config_path.native_file_string(),info);
        }
    }
  return location;
}
