/* Prints the location of an archive

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <iostream>
#include "parse_common_options.hpp"
#include "parse_unknown_options.hpp"
#include "check_extra_args.hpp"
#include "command_initializer.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/exception.hpp"
#include "arx_error.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

extern string archive_location(const string &archive,
                               const Command_Info &info);

int whereis_archive(list<string> &argument_list, const command &cmd);

static command_initializer whereis_archive_init(command("whereis-archive",
"Print the location of an archive",
"usage: whereis-archive [options] archive",
"Print the location of an archive.  It must have been previously\n\
registered with \"arx register-archive\"",
whereis_archive,"User",true));

int whereis_archive(list<string> &argument_list, const command &cmd)
{
  Command_Info info(cmd);

  while(parse_common_options(argument_list,info))
    {}
  parse_unknown_options(argument_list,info);

  if(argument_list.empty())
    {
      throw arx_error("Need an archive name",info);
    }

  string archive(*(argument_list.begin()));
  argument_list.pop_front();
  check_extra_args(argument_list,info);
  
  path home(getenv("HOME"));
  path config_path(home / ".arch-params/=locations" / archive);
  
  if(!exists(config_path))
    {
      throw arx_error("Archive is not registered: " + archive,info);
    }
  else
    {
      string location(archive_location(archive,info));
      cout << location << endl;
    }
  return 0;
}
