/* Copies old_file to temp_file, appends new_element to temp_file, and
   then renames the temp_file to old_file.

   This function is used by the notify funstions to make an atomic
   append.  All of this singing and dancing is required to maintain
   transactionality.  It really should use the tmp name facility in
   ISO C, so that you wouldn't have to supply a temp_file_name.

   Copyright 2002, 2003 Walter Landry and the Regents of the
   University of California.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include <fstream>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include <cstdio>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void atomic_append(const path &old_name,
		   const path &temp_name, const string &new_element)
{
  /* If the file exists, then make a copy.  Otherwise, we can start
     from nothing. */

  if(fs::exists(old_name))
    {
      fs::copy_file(old_name,temp_name);
    }  
  fs::ofstream temp_file(temp_name,ios::out|ios::app);
  if(temp_file)
    {
      temp_file << new_element << "\n";
    }
  else
    {
      throw (string) "Can't open the temp file for appending: "
        + temp_name.string();
    }

  /* Have to use ANSI C rename instead of boost::filesystem rename,
     because boost::filesystem won't atomically replace the target, while
     ANSI C will on POSIX systems. */
  if(rename(temp_name.string().c_str(),old_name.string().c_str())==-1)
    {
      throw string("Can't rename:") + temp_name.string() + " "
        + old_name.string();
    }
}

