/* Recursively notifies all of the category for a particular
   archive.

   Copyright 2002, 2003 Walter Landry and the Regents of the
   University of California.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include <list>
#include <fstream>
#include <algorithm>

#include "boost/regex.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/convenience.hpp"

#include "get_categories.h"
#include "atomic_append.h"
#include "notify_branches.h"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void notify_categories(const string &notify_parser, 
                       const path &notify_directory, const string& targets,
                       const string &archive,
		       bool categories, bool branches=false,
		       bool versions=false, bool revisions=false)
{
  /* Get a list of the categories that have already been notified */
  list<string> archive_category_list;
  const path archive_path=notify_directory / archive;
  if(categories)
    {
      fs::ifstream archive_file(archive_path / "category_list");
      string archive_category;
      while(getline(archive_file,archive_category))
	archive_category_list.push_back(archive_category);
    }

  list<string> category_list(get_categories(archive));

  const path rules_path=notify_directory / "rules";

  for(list<string>::const_iterator category=category_list.begin();
      category!=category_list.end();++category)
    {

      string rules=(notify_directory / "rules").string();
      
      string arch_vars=" ARCHARCHIVES=" + archive
        + " ARCHCATEGORIES=" + *category;

      string notify_begin=notify_parser + " " + rules + arch_vars + " ";
      string notify_end= + "--revision >> " + rules + ".out 2> "
        + rules + ".err";

      /* If we're notifying categories */
      if(categories)
	/* and we haven't notified this category before */
	if(find(archive_category_list.begin(),archive_category_list.end(),
		*category)==archive_category_list.end()
	   /* and the notify succeeds */
           && !system((notify_begin + archive + notify_end).c_str()))
	  {
	    /* Then update the notified list. */
            if(!fs::exists(archive_path))
              fs::create_directory(archive_path);
	    atomic_append(archive_path / "category_list",
			  archive_path / ",,category_list",*category);
	  }

      match_results<string::const_iterator> m;
      /* If we are doing branches, versions, or revisions */
      if((branches || versions || revisions)
	 /* And we're doing either this particular category */
	 && (regex_search(targets,m,
			  regex("^" + (*category)
				+ "[^:\n]*--(branch|version|revision):"))
	     /* or everything for this archive */
	     || regex_search(targets,m,
			     regex("^" + archive
				   + "--(branch|version|revision):"))))
	{
	  /* Then notify the branches */
	  notify_branches(notify_parser,notify_directory,targets,archive,
                          *category,branches,versions,revisions);
	}
    }
}

