/* A collection of commands to get or set the inventory method

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#ifndef ARX_INVENTORY_METHOD_HPP
#define ARX_INVENTORY_METHOD_HPP

#include <string>
#include "Command_Info.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "tree_root.hpp"
#include "get_option_from_file.hpp"
#include "set_option_in_file.hpp"
#include "Inventory_Regexes.hpp"

namespace Inventory_Method
{
  using namespace boost;
  namespace fs=boost::filesystem;
  using fs::path;

  enum inventory_method {names_inventory, explicit_inventory,
                         implicit_inventory};
  
  inline path filename(const path &directory, const Command_Info &info)
  {
    return tree_root(directory, info) / "{arch}/=tagging-method";
  }

  extern inventory_method get(const path &directory, const Command_Info &info);
  extern inventory_method get(const path &directory,
                              Inventory_Regexes &inv_regexes,
                              const Command_Info &info);

  extern void set(const inventory_method &new_method,
                  const path &directory, const Command_Info &info);
  extern void set(const inventory_method &new_method,
                  const Inventory_Regexes &inv_regexes,
                  const path &directory,
                  const Command_Info &info);
};

#endif
