/* An class to hold the characteristics of a file: path, inventory
   tag, and whether it is a link.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#ifndef ARX_FILE_ATTRIBUTES_HPP
#define ARX_FILE_ATTRIBUTES_HPP

#include <string>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/exception.hpp"
#include <bitset>
#include <sys/stat.h>
#include "Tom_encode.hpp"

class file_attributes
{
public:
  boost::filesystem::path file_path;
  bool link;
  std::string inventory_tag;
  std::bitset<9> permissions;
  
  file_attributes(const boost::filesystem::path &File_Path):
    file_path(File_Path), link(boost::filesystem::is_link(File_Path))
  {
    file_stat();
  }
  
  file_attributes(const boost::filesystem::path &File_Path,
                  const std::string &tag):
    file_path(File_Path), link(boost::filesystem::is_link(File_Path)),
    inventory_tag(tag)
  {
    file_stat();
  }

  bool operator<(const file_attributes &attribute)
  {
    return file_path.native_file_string()
      <attribute.file_path.native_file_string();
  }
  bool operator==(const file_attributes &attribute)
  {
    return file_path.native_file_string()
      ==attribute.file_path.native_file_string()
      && inventory_tag==attribute.inventory_tag
      && permissions==attribute.permissions;
  }
private:

  /* This is all very Unix specific.  It should be abstracted away in
     the boost libraries, but they still haven't decided how to do
     this. */
  void file_stat()
  {
    if(!link)
      {
        struct stat path_stat;
        if(::stat(file_path.native_file_string().c_str(),&path_stat))
          {
            boost::throw_exception
              (boost::filesystem::filesystem_error("file_stat",
                                                   file_path,
                                                   boost::filesystem::detail::system_error_code()));
          }
        permissions[8]=path_stat.st_mode & S_IRUSR;
        permissions[7]=path_stat.st_mode & S_IWUSR;
        permissions[6]=path_stat.st_mode & S_IXUSR;
        permissions[5]=path_stat.st_mode & S_IRGRP;
        permissions[4]=path_stat.st_mode & S_IWGRP;
        permissions[3]=path_stat.st_mode & S_IXGRP;
        permissions[2]=path_stat.st_mode & S_IROTH;
        permissions[1]=path_stat.st_mode & S_IWOTH;
        permissions[0]=path_stat.st_mode & S_IXOTH;
      }
  }
};

inline bool inventory_tag_cmp(const file_attributes &a,
                              const file_attributes &b)
{
  return a.inventory_tag<b.inventory_tag;
}

inline bool inventory_tag_eq(const file_attributes &a,
                             const file_attributes &b)
{
  return a.inventory_tag==b.inventory_tag;
}

inline bool Tom_encoded_tag_cmp(const file_attributes &a,
                                const file_attributes &b)
{
  return Tom_encode(a.inventory_tag) < Tom_encode(b.inventory_tag);
}

inline bool Tom_encoded_tag_eq_string(const file_attributes a,
                                      const std::string b)
{
  return Tom_encode(a.inventory_tag)==Tom_encode(b);
}


#endif
