/* The is the main file for ArX, a distributed revision control
   system. 

   Copyright 2001, 2002 Tom Lord
   Copyright 2002, 2003 Walter Landry and the Regents of the
   University of California.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */


#include <list>
#include <cstdio>
#include <string>
#include <cassert>
#include <iostream>
#include "command.hpp"
#include "arx_error.hpp"
#include "Singleton.h"

using namespace std;

extern bool process_generic_options(const list<string> &argument_list);

/* A list of commands that files can independently add themselves to. */

typedef Loki::SingletonHolder<list<command> > cmd_list;

int main(int argv, char *argc[])
{
  list<string> argument_list;
  for(int i=1;i<argv;++i)
    {
      argument_list.push_back(string(argc[i]));
    }

  /* Process generic options (--help, --version, etc.).  If there are
     arguments but no such options, then continue. */

  if(process_generic_options(argument_list))
    {
      /* Now actually do the command */
      assert(!argument_list.empty());
      string subcommand=*argument_list.begin();
      
      /* If we've implemented this command in C++, then do it */
      list<command>::iterator action=find(cmd_list::Instance().begin(),
                                          cmd_list::Instance().end(),subcommand);

      if(action!=cmd_list::Instance().end())
        {
          /* Remove the command argument */
          argument_list.pop_front();
          try {
            action->eval(argument_list);
          }
          catch (arx_error &err)
            {
              if(err.info.verbosity>silent)
                cerr << err.info.cmd.name << ": " << err.message << endl;
              exit(err.error_code);
            }
        }
      else
        /* Otherwise, fall back to the shell implementation.  We have
           to quote all of the arguments, otherwise special characters
           will not be passed correctly. */
        {
          subcommand="arx-shell ";
          for(list<string>::iterator i=argument_list.begin();
              i!=argument_list.end(); ++i)
            {
              subcommand+=" \"" + *i + "\"";
            }

          /* Not portable.  Need to fix for various systems until all
             of the shell commands are eliminated. */
          exit(system(subcommand.c_str()) >> 8);
        }
    }
  exit(0);
}

