/* Commands to get the inventory method and associated regexes.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include "Command_Info.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "tree_root.hpp"
#include "get_option_from_file.hpp"
#include "set_option_in_file.hpp"
#include "Inventory_Method.hpp"
#include <iostream>

namespace Inventory_Method
{
  using namespace std;
  using namespace boost;
  namespace fs=boost::filesystem;
  using fs::path;

  inventory_method get(const path &directory,
                       const Command_Info &info)
  {
    Inventory_Regexes inv_regexes;
    return get(directory,inv_regexes,info);
  }

  inventory_method get(const path &directory,
                       Inventory_Regexes &inv_regexes,
                       const Command_Info &info)
  {
    path config_file(filename(directory,info));
    
    inventory_method result;
    try
      {
        fs::ifstream regex_file(config_file);
        std::string method, regexes;
        /* Get the inventory tagging method */
        getline(regex_file,method);
        if(method=="names")
          {
            result=names_inventory;
          }
        else if(method=="explicit")
          {
            result=explicit_inventory;
          }
        else if(method=="implicit")
          {
            result=implicit_inventory;
          }
        else
          {
            throw arx_error("Bad inventory method in "
                            + config_file.native_file_string()
                            + "\n\t" + method,info);
          }
        /* Now get all of the regexes. */
        
        while(getline(regex_file,regexes))
          {
            if(regexes.substr(0,6)=="source")
              {
                inv_regexes.source=regex(regexes.substr(7));
              }
            else if(regexes.substr(0,8)=="precious")
              {
                inv_regexes.precious=regex(regexes.substr(9));
              }
            else if(regexes.substr(0,6)=="backup")
              {
                inv_regexes.backup=regex(regexes.substr(7));
              }
            else if(regexes.substr(0,4)=="junk")
              {
                inv_regexes.junk=regex(regexes.substr(5));
              }
            else if(regexes.substr(0,12)=="unrecognized")
              {
                inv_regexes.unrecognized=regex(regexes.substr(13));
              }
            /* The exclude regex is ignored, since it basically
               defines the control files. */
            else if(regexes.substr(0,7)=="exclude")
              {
                if(info.verbosity>=default_output)
                  cerr << "Warning: exclude regex ignored in "
                    + config_file.native_file_string()
                       << std::endl;
              }
            else if(!regexes.empty())
              {
                throw arx_error("Can't parse tagging-method file: "
                                + config_file.native_file_string()
                                + "\nBad line is: \n" + regexes,info);
              }
          }
      }
    catch (boost::filesystem::filesystem_error &fs_error)
      {
        throw arx_error("Problem opening or writing a file:\n"
                        + fs_error.who() + "\n"
                        + fs_error.path1().native_file_string() + "\n"
                        + fs_error.path2().native_file_string() + "\n",
                        info);
      }
    return result;
  }
};

