/* Commands to set the inventory method and associated regexes

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include "Command_Info.hpp"
#include "arx_error.hpp"
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "tree_root.hpp"
#include "get_option_from_file.hpp"
#include "set_option_in_file.hpp"
#include "Inventory_Method.hpp"
#include <cstdio>

namespace Inventory_Method
{
  using namespace std;
  using namespace boost;
  namespace fs=boost::filesystem;
  using fs::path;
  
  void set(const inventory_method &new_method,
           const path &directory,
           const Command_Info &info)
  {
    Inventory_Regexes inv_regexes;
    const path config_file(filename(directory,info));
    if(exists(config_file))
      get(config_file,inv_regexes,info);
    set(new_method,inv_regexes,config_file.branch_path(),info);
  }

  void set(const inventory_method &new_method,
           const Inventory_Regexes &inv_regexes,
           const path &directory,
           const Command_Info &info)
  {
    string option;
    if(new_method==names_inventory)
      {
        option="names";
      }
    else if(new_method==explicit_inventory)
      {
        option="explicit";
      }
    else if(new_method==implicit_inventory)
      {
        option="implicit";
      }
    else
      {
        throw arx_error("Invalid inventory tagging method: " + new_method,
                        info);
      }
    try
      {
        const path temp_path(",,tagging_method");
        fs::ofstream temp_file(temp_path);
        temp_file << option << endl;
        temp_file << "source " << inv_regexes.source.str() << endl;
        temp_file << "precious " << inv_regexes.precious.str() << endl;
        temp_file << "backup " << inv_regexes.backup.str() << endl;
        temp_file << "junk " << inv_regexes.junk.str() << endl;
        temp_file << "unrecognized " << inv_regexes.unrecognized.str() << endl;

        /* Have to use ANSI C rename instead of boost::filesystem
           rename, because boost::filesystem won't atomically replace
           the target, while ANSI C will on POSIX systems. */
        if(rename(temp_path.native_file_string().c_str(),
                  filename(directory,info).native_file_string().c_str())!=0)
          {
            throw arx_error("Can't rename: " + 
                            temp_path.native_file_string() + " "
                            + filename(directory,info).native_file_string(),
                            info);
                            
          }
      }
    catch (fs::filesystem_error &fs_error)
      {
        throw arx_error("Problem when writing the =tagging-method file.  The problem function was\n\t"
                        + fs_error.who() + "\nand the problem file(s) are:\n\t"
                        + fs_error.path1().native_file_string() + "\n\t"
                        + fs_error.path2().native_file_string(),info);
      }
  }
};

