/* Creates a registration for an archive.

   Copyright (C) 2001, 2002 Tom Lord
   Copyright (C) 2002, 2003 Walter Landry and the Regents of the
                                  University of California

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "arx_error.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

void create_archive_registration(const string &archive, const string &location,
                                 const Command_Info &info)
{
  path home(getenv("HOME"));
  path location_path(home / ".arch-params/=locations");
  if(!exists(location_path))
    {
      try
        {
          create_directory(location_path);
        }
      catch (fs::filesystem_error &fs_error)
        {
          throw arx_error("Could not create the location directory: "
                          + location_path.native_file_string(),info);
        }
    }
  else if(!is_directory(location_path))
    {
      throw arx_error("INTERNAL ERROR: \n" + location_path.native_file_string()
                      + "\nis not a directory",info);
    }

  path config_path(location_path / archive);
  if(exists(config_path))
    {
      throw arx_error("Archive is already registered: " + archive,info);
    }
  else
    {
      try
        {
          fs::ofstream config_file(config_path);
          config_file << location << endl;
        }
      catch (fs::filesystem_error &fs_error)
        {
          throw arx_error("Can't open the config file: "
                          + config_path.native_file_string(),info);
        }
    }
}
