/* Get a configuration option from a file in the .arch-params
   directory of the home directory.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include <list>
#include <map>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include "Command_Info.hpp"
#include "arx_error.hpp"
#include "get_option_from_file.hpp"

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

string get_config_option(const string &filename, const Command_Info &info)
{
  /* A static map so that we don't have to reopen a file every time we
     need the option. */
  static map<string,string> config_map;

  string config_option=config_map[filename];
  if(config_option.empty())
    {
      path home(getenv("HOME"));
      path config_path(home / ".arch-params" / filename);

      config_option=get_option_from_file(config_path,info);
      config_map[filename]=config_option;
    }
  return config_option;
}
