/* Set the permissions of a particular file.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <bitset>
#include "boost/filesystem/operations.hpp"
#include "boost/filesystem/fstream.hpp"
#include "boost/filesystem/exception.hpp"
#include <sys/stat.h>

// #include <iostream>

using namespace std;
using namespace boost;
namespace fs=boost::filesystem;
using fs::path;

/* This is all very Unix specific.  It should be abstracted away in
   the boost libraries, but they still haven't decided how to do
   this. */

void set_permissions(const path &file_path, const bitset<9> &permissions)
{
  /* Permissions on symlinks can not be set. */
  if(!is_link(file_path))
    {
      struct stat path_stat;
      if(::stat(file_path.native_file_string().c_str(),&path_stat))
        {
          boost::throw_exception
            (boost::filesystem::filesystem_error
             ("set_permissions::stat",file_path,
              boost::filesystem::detail::system_error_code()));
        }

      mode_t on(0),off(0);

//       cout << "permissions " << file_path.string() << " "
//            << oct
//            << permissions.to_ulong() << " "
//            << path_stat.st_mode << " ";
      
      (permissions[8] ? on : off) |= S_IRUSR;
      (permissions[7] ? on : off) |= S_IWUSR;
      (permissions[6] ? on : off) |= S_IXUSR;
      (permissions[5] ? on : off) |= S_IRGRP;
      (permissions[4] ? on : off) |= S_IWGRP;
      (permissions[3] ? on : off) |= S_IXGRP;
      (permissions[2] ? on : off) |= S_IROTH;
      (permissions[1] ? on : off) |= S_IWOTH;
      (permissions[0] ? on : off) |= S_IXOTH;

      path_stat.st_mode|=on;
      path_stat.st_mode&=~off;

//       cout << path_stat.st_mode << endl;

      if(::chmod(file_path.native_file_string().c_str(),path_stat.st_mode)!=0)
        {
          boost::throw_exception
            (boost::filesystem::filesystem_error
             ("set_permissions::chmod",file_path,
              boost::filesystem::detail::system_error_code()));
        }
    }
}

