/* Makes sure that a particular name has all of the required
   components.

   Copyright 2003 Walter Landry

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
   USA */

#include <string>
#include "Command_Info.hpp"
#include "package_level.hpp"
#include "parse_package_name.hpp"
#include "arx_error.hpp"

using namespace std;

void valid_package_name(const string &full_name,
                        const Command_Info &info,
                        const package_level &level=Archive,
                        const bool &require_archive=false)
{
  string archive, category, branch, version, revision;
  parse_package_name(full_name,archive,category,branch,version,revision,
                     info,require_archive);
  if(level==Category && category.empty())
    {
      throw arx_error("category required: " + full_name,info);
    }
  else if(level==Branch && branch.empty())
    {
      throw arx_error("branch required: " + full_name,info);
    }
  else if(level==Version && version.empty())
    {
      throw arx_error("version required: " + full_name,info);
    }
  else if(level==Revision && revision.empty())
    {
      throw arx_error("revision required: " + full_name,info);
    }
}
