/* tag: Scott Parish Sun Feb  10 13:01:05 2002 (misc.c)
 */
/* misc.c -
 *
 ****************************************************************
 * Copyright (C) 2002 Scott Parish
 * Copyright (C) 2003 Walter Landry
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 dated June, 1991.

 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 * 
 * In addition, the strsep implementation is covered by the following
 * copyright:
 *
 * Copyright (c) 1990, 1993
 *	The Regents of the University of California.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the University nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE REGENTS AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 */

#include <config.h>
#include <string.h>
#include "hackerlab/mem/mem.h"
#include "hackerlab/char/str.h"
#include "ftp-utils/clients/misc.h"

#ifndef HAVE_STRSEP

/* Not all Unix's have strsep (e.g. Irix), so we provide one here. */

char *
strsep(stringp, delim)
	register char **stringp;
	register const char *delim;
{
	register char *s;
	register const char *spanp;
	register int c, sc;
	char *tok;

	if ((s = *stringp) == NULL)
		return (NULL);
	for (tok = s;;) {
		c = *s++;
		spanp = delim;
		do {
			if ((sc = *spanp++) == c) {
				if (c == 0)
					s = NULL;
				else
					s[-1] = 0;
				*stringp = s;
				return (tok);
			}
		} while (sc != 0);
	}
}

#endif

/*
 * dirfold: take a directory and "fold" out all the '.' and '..'s
 *
 * example: dirfold(limits, "/tmp/.././home/srp/images/..")
 * should return "/home/srp"
 *
 * Note: this function modifies the string passed in, it does not return a
 * new string
 */
char *
dirfold (alloc_limits limits, char *dir)
{
  char *buf, *this, *next;
  int dir_i = 0;

  this = next = buf = str_save (limits, dir);
  while ((this = strsep (&next, "/")) != NULL)
    {
      if (str_length (this) == 0 || (str_length (this) == 1 && this[0] == '.'))
	continue;
      else if (str_length (this) == 2 && *this == '.' && this[1] == '.')
	{
	  if (dir_i > 0)
	    dir_i = strrchr (dir, '/') - dir;
	  dir[dir_i] = 0;
	}
      else
	{
	  dir[dir_i++] = '/';
	  strcpy (dir + dir_i, this);
	  dir_i += str_length (this);
	}
    }
  lim_free (limits, buf);

  if (!str_length (dir))
      str_cpy (dir, "/");

  return dir;
}
