/* tag: Scott Parish Sun Feb  2 13:03:45 2002 (sftp-protocol.h)
 */
/* sftp-protocol.h -
 *
 ****************************************************************
 * Copyright (C) 2002 Scott Parish
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 dated June, 1991.

 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */

#ifndef INCLUDE__SFTP_PROTOCOL__PROTOCOL_H
#define INCLUDE__SFTP_PROTOCOL__PROTOCOL_H

#include "hackerlab/machine/types.h"
#include "hackerlab/os/stdarg.h"
#include "hackerlab/mem/alloc-limits.h"

/* TODO: look through ssh/tcp/ethernet specks to find an optimal size */
#define SFTP_RWSIZE 16384
#define SFTP_DEFAULT_DIR_MODE 0755
#define SFTP_DEFAULT_FILE_MODE 0664


/* automatically generated __STDC__ prototypes */
extern int sftp_client_connect_and_login (int * in_fd,
					 int * out_fd,
					 alloc_limits limits,
					 int * errn,
					 int * code,
					 t_uchar ** text,
					 long * text_len,
					 t_uchar * host);
extern int sftp_client_cwd (alloc_limits limits,
			   int * errn,
			   int * code,
			   t_uchar ** text,
			   long * text_len,
			   int in_fd,
			   int out_fd,
			   t_uchar * path);
extern int sftp_client_cdup (alloc_limits limits,
			    int * errn,
			    int * code,
			    t_uchar ** text,
			    int in_fd,
			    int out_fd);
extern int sftp_client_begin_retr (alloc_limits limits,
				  int * errn,
				  int * code,
				  t_uchar ** text,
				  int in_fd,
				  int out_fd,
				  t_uchar * path);
extern int sftp_client_end_retr (alloc_limits limits,
				int * errn,
				int * code,
				t_uchar ** text,
				int in_fd,
				int out_fd);
extern int sftp_client_rename (alloc_limits limits,
			      int * errn,
			      int * code,
			      t_uchar ** text,
			      int in_fd,
			      int out_fd,
			      t_uchar * from,
			      t_uchar * to);
extern int sftp_client_unlink (alloc_limits limits,
			    int * errn,
			    int * code,
			    t_uchar ** text,
			    int in_fd,
			    int out_fd,
			    t_uchar * path);
extern int sftp_client_rmd (alloc_limits limits,
			   int * errn,
			   int * code,
			   t_uchar ** text,
			   int in_fd,
			   int out_fd,
			   t_uchar * path);
extern int sftp_client_mkd (alloc_limits limits,
			   int * errn,
			   int * code,
			   t_uchar ** text,
			   int in_fd,
			   int out_fd,
			   t_uchar * path);
extern int sftp_client_pwd (alloc_limits limits,
			   int * errn,
			   int * code,
			   t_uchar ** text,
			   int in_fd,
			   int out_fd);
extern int sftp_client_list (alloc_limits limits,
			    int * errn,
			    int * code,
			    t_uchar ** text,
			    int in_fd,
			    int out_fd,
			    int data_fd,
			    t_uchar *path,
			    int longfmt);
extern int sftp_client_get (alloc_limits limits,
			    int * errn,
			    int * code,
			    t_uchar ** text,
			    int in_fd,
			    int out_fd,
			    int data_fd,
			    t_uchar *path);
extern int sftp_client_put (alloc_limits limits,
			    int * errn,
			    int * code,
			    t_uchar ** text,
			    int in_fd,
			    int out_fd,
			    int data_fd,
			    int connect_out,
			    t_uchar *path);
#endif  /* INCLUDE__SFTP_PROTOCOL__PROTOCOL_H */
