/* cwd.c: 
 *
 ****************************************************************
 * Copyright (C) 2002 Tom Lord
 * Copyright (C) 2003 Environment Canada - Meteorological Service of Canada
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; version 2 dated June, 1991.

 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * General Public License for more details.

 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
 * USA
 */


#include "hackerlab/os/errno.h"
#include "hackerlab/os/unistd.h"
#include "hackerlab/char/str.h"
#include "hackerlab/fs/cwd.h"



char *
current_working_directory (int * errn, struct alloc_limits * limits)
{
  char * path;
  size_t sizeof_path;

  sizeof_path = 4096;
  path = lim_malloc (limits, sizeof_path);
  if (!path)
    {
    enomem_error:
      *errn = ENOMEM;
      if (path)
	lim_free (limits, path);
      return 0;
    }

  while (1)
    {
      if (getcwd (path, sizeof_path))
	{
	  char * answer;
	  answer = lim_realloc (limits, path, str_length ((const t_uchar *)path) + 1);
	  if (!answer)
	    goto enomem_error;
	  return answer;
	}
      else if (errno == ERANGE)
	{
	  char * new_path;
	  sizeof_path *= 2;
	  new_path = lim_realloc (limits, path, sizeof_path);
	  if (!new_path)
	    goto enomem_error;
	}
      else
	{
	  *errn = errno;
	  lim_free (limits, path);
	  return 0;
	}
    }
}



/* tag: Tom Lord Fri Feb 22 04:10:53 2002 (cwd.c)
 */
