#!/bin/sh

# This script requires you to have already set up a default archive
# and id.  It will create a category called hello in your default
# archive.  It will be removed at the end, but if something breaks
# along the way, you can manually clean up with
#
#   rm -rf hello/ hello--german/ hello--germain/
#   arx delete-category hello
#
# Copyright (C) 2002, 2003 Walter Landry and the Regents
#                          of the University of California
# 
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; version 2 dated June, 1991.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA

mkdir hello
cd hello
echo "echo Hello, World" > Hello
echo "Summary: initial" > ./`arx create-version --non-interactive hello--main--1.0`
arx add Hello
arx commit

# Make the german branch

arx create-branch --non-interactive hello--main--1.0 hello--german--1.0 ../hello--german
cd ../hello--german
echo "Summary: Initial branch from main" > `arx make-log --non-interactive`
arx commit

# Commit to the main branch as well. Then remove the old hello
# directory and arx get a new one.  

# We have to do it this way because you can't directly update main
# from german, because main doesn't have the logs from german.

echo "Summary: Initial merge from german" > `arx make-log --non-interactive hello--main--1.0`
arx commit hello--main--1.0
rm -rf ../hello/
arx get hello--main--1.0 ../hello

# Modify and commit the main branch

cd ../hello
echo "echo Hello World.  Goodbye" > Hello
echo "Goodbye" > bye
arx add bye
echo "Summary: Added goodbye" > `arx make-log --non-interactive`
arx commit

# Exercise replay

arx replay ../hello--german ../hello--germain hello--main--1.0

# Update the german branch from the main branch

arx update --in-place ../hello--german hello--main--1.0

cd ../hello--german
echo "Summary: update from main" > `arx make-log --non-interactive`
arx commit

# Modify the german branch

echo "Guten Tag" > Hello
echo "Summary: tranlated Hello" > `arx make-log --non-interactive`
arx commit

# Update the main branch from the german branch

# arx update --in-place ../hello hello--german--1.0

arx star-merge --in-place ../hello hello--main--1.0 hello--german--1.0

cd ..
rm -rf hello/ hello--german/ hello--germain/
arx delete-category hello
