#!/usr/bin/python
#
# Try to identify added, removed and moved files after applying a
# regular patch to an Arch project tree.
#
# We take the list of added and removed files from tree-lint and then
# try to identify which removed files that are mostly identical to some
# added file.
#
# This currently does NOT work for ArX.
#
# Copyright 2003 Jan Harkes
# Modified 2003 Walter Landry

# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the
# License, or (at your option) any later version.

# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
# USA

import sys
import os
import re
import difflib

TREELINT = os.popen("arx tree-lint").readlines()
PRISTINE = os.popen("arx find-pristine `arx ls-pristines`").readline()[:-1]
MOVE_TAG = "arx move %s %s"
ADD_TAG  = "arx add %s"
DEL_TAG  = "arx delete %s"

apply = sys.argv[1:] and sys.argv[1] == '-f'

def do(cmd):
    if apply:
	os.system(cmd)

adds = []
dels = []
for line in TREELINT:
    if line[:2] != './': continue
    line = line[:-1]
    m = re.match("^\./(.*).arch-ids/(.*)\.id$", line)
    if m: dels.append(os.path.join(m.group(1), m.group(2)))
    else: adds.append(line)

moved = []
for deleted in dels:
    file = os.path.join(PRISTINE, deleted)
    if os.path.isdir(file):
	continue

    d = open(file).readlines()
    print "checking", deleted

    matches = []
    for added in adds:
	if os.path.isdir(added):
	    continue

	a = open(added).readlines()
	match = difflib.SequenceMatcher(difflib.IS_LINE_JUNK, d, a).quick_ratio()
	if match <= 0.60: continue

	print "\tfound possible match %s ~%.2f%% identical" % (added, match*100)
	matches.append((1 - match, added))
    if not matches:
	continue

    matches.sort()
    match = matches[0][1]
    print "*** moving %s to %s" % (deleted, match)

    do(MOVE_TAG % (deleted, match))
    moved.append(deleted)
    adds.remove(match)

print "\nremoving tags for deleted files"
for deleted in dels:
    if not deleted in moved:
	print "\t%s" % deleted
	do(DEL_TAG % deleted)

print "\ntagging new files"
for added in adds:
    print "\t%s" % added
    do(ADD_TAG % added)

