;; A mode for editing log files.  It binds keys to make it easy to
;; commit.

;; Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
;; of California

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(add-hook 'arx-log-mode-hook
	  (lambda () "Simple usage message"
	    (message "Type C-c C-c to commit")))

(define-derived-mode arx-log-mode text-mode "arx-log"
  "Major Mode for editing arx logs.
\\[arx-commit] save the file, kill the buffer, and commit the changes")

(define-key arx-log-mode-map "\C-c\C-c" 'arx-commit)

;; A function to actually do the commit.

(put 'arx-commit-error
     'error-conditions
     '(error arx-error arx-commit-error))

(put 'arx-commit-error 'error-message "arx-commit failed")

(defun arx-commit ()
  "Commit the current changes.  This should only be invoked from
within arx-log-mode."
  (interactive)
  (save-buffer 0)
  (save-current-buffer
    (set-buffer (get-buffer-create "*arx*"))
    (erase-buffer))
  (if (= 0 (call-process "arx" nil "*arx*" t "commit"))
      (progn
	;; If adding a new category, add it to the cache
	(if (and arx-new-category arx-category-list)
	    (setcdr arx-category-list (cons arx-new-category
					      (cdr arx-category-list))))
	;; If adding a new branch, add it to the cache
	(if (and arx-new-branch arx-branch-alist)
	    (let* ((category (car (arx-split-names arx-new-branch)))
		   (branches (assoc category arx-branch-alist)))
	      (if (car branches)
		  (setcdr branches (cons arx-new-branch (cdr branches))))))
	;; If adding a new version, add that to the cache
	(if (and arx-new-version arx-version-alist)
	    (let* ((category (car (arx-split-names arx-new-version)))
		   (branch
		    (concat category "--" (car (cdr (arx-split-names
						     arx-new-version)))))
		   (versions (assoc branch arx-version-alist)))
	      (if (car versions)
		  (setcdr versions (cons arx-new-version (cdr versions))))))
	;; Delete the revision-alist cache for the version that is
	;; committed.
	(if arx-revision-alist
	    (let ((version (car (cdr (split-string (arx-get-tree-version)
						   "/"))))
		  (newlist))
	      (dolist (temp arx-revision-alist)
		(if (not (equal (car temp) version))
		    (setq newlist (cons temp newlist))))
	      (setq arx-revision-alist newlist)))
        (message "Revision committed")
	(kill-buffer (current-buffer)))
    (progn (display-buffer "*arx*" t)
	   (signal 'arx-commit-error nil))))
