;; Find out what has changed from the previous revision.

;; Copyright (C) 2002, 2003 Walter Landry and the Regents of the University
;; of California

;; This program is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 2 of the License, or
;; (at your option) any later version.

;; This program is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with this program; if not, write to the Free Software
;; Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

(put 'arx-what-changed-error
     'error-conditions
     '(error arx-error arx-what-changed-error))

(put 'arx-what-changed-error 'error-message "arx-what-changed failed")

(defun arx-what-changed (old_revision)
  "Find out what has changed from the previous revision."
  (interactive (list (completing-read
		      "Revision name: "
		      'arx-complete-revisions)))
  (save-current-buffer
    (set-buffer (get-buffer-create "*arx*"))
    (erase-buffer))
  (let ((return-value
	 (call-process "arx" nil "*arx*" t "what-changed" old_revision)))
    (if (= 0 return-value)
	  ;; If nothing has changed
	  ;; Just print out no changes
	  (message "No changes")
	;; Otherwise, display the *arx* buffer and go to dired mode
	;; on the ,,what-changed directory
      (if (= 1 return-value)
	  (progn
	    (dired (save-current-buffer
		     ;; Change directory to the tree-root
		     (call-process "arx" nil "*arx*" t "tree-root")
		     (set-buffer "*arx*")
		     (previous-line 1)
		     (kill-region (progn (beginning-of-line) (point))
				  (progn (end-of-line) (point)))
		     (let ((tree-root (car kill-ring-yank-pointer)))
		       (cd tree-root)
		       ;; return the name of the directory where the
		       ;; changes are.
		       (call-process "ls" nil "*arx*" t "-lt")
		       (goto-char (point-min))
		       (re-search-forward ",,what-changed")
		       (kill-region (progn (beginning-of-line) (point))
				    (progn (end-of-line) (point)))
		       (let ((dir-name
			      (car (nthcdr 8 (split-string
					      (car kill-ring-yank-pointer))))))
			 (kill-region (re-search-backward "total")
				      (point-max))
			 (goto-char (point-min))
			 (concat tree-root "/" dir-name)))))
	    (revert-buffer)
	    (arx-what-changed-mode)
	    (arx-mode)
	    (display-buffer "*arx*" t)
	    ;; I have to rebuild the subdirectory alist because it gets
	    ;; confused after getting into arx-what-changed-mode.
	    (dired-build-subdir-alist))
	(progn (display-buffer "*arx*" t)
	       (signal 'arx-what-changed-error nil))))))


(define-derived-mode arx-what-changed-mode  dired-mode "arx-what-changed"
  "Major Mode for browsing what-changed directories
\\[arx-what-changed-delete-dired] quit the mode and delete the ,,what-changed directory.")

(define-key arx-what-changed-mode-map "q" 'arx-what-changed-delete-dired)

(defun arx-what-changed-delete-dired ()
  "Deletes the ,,what-changed.* directories and kills the buffer"
  (interactive)
  (call-process "rm" nil "*arx*" t "-rf" (expand-file-name dired-directory))
  (kill-buffer (current-buffer))
)


